/*-------------------------------------------------------------------------
 |                                                                         
 |                    SAS SETUP FILE FOR ICPSR 06845
 |             NATIONAL HOUSEHOLD SURVEY ON DRUG ABUSE, 1982
 |
 |
 | SAS setup sections are provided for the ASCII version of this data
 | collection.  These sections are listed below:
 |
 | PROC FORMAT:  creates user-defined formats for the variables. Formats
 | replace original value codes with value code descriptions. Only
 | variables with user-defined formats are included in this section.
 |
 | DATA:  begins a SAS data step and names an output SAS data set.
 |
 | INFILE:  identifies the input file to be read with the input statement.
 | Users must replace the "data-filename" with a filename specifying the
 | directory on the user's computer system in which the downloaded and
 | unzipped data file is physically located (e.g.,
 | "c:\temp\06845-0001-data.txt").
 |
 | INPUT:  assigns the name, type, decimal specification (if any), and
 | specifies the beginning and ending column locations for each variable
 | in the data file.
 |
 | LABEL:  assigns descriptive labels to all variables. Variable labels
 | and variable names may be identical for some variables.
 |
 | MISSING VALUE RECODES:  sets user-defined numeric missing values to
 | missing as interpreted by the SAS system. Only variables with
 | user-defined missing values are included in this section.
 |
 | If any variables have more than one missing value, they are assigned
 | to the standard missing value of a single period (.) in the statement
 | below. To maintain the original meaning of missing codes, users may want
 | to take advantage of the SAS missing values (the letters A-Z or an
 | underscore preceded by a period).
 |
 | An example of a standard missing value recode:
 |
 |   IF (RELATION = 98 OR RELATION = 99) THEN RELATION = .; 
 |
 | The same example using special missing value recodes:
 |
 |    IF RELATION = 98 THEN RELATION = .A;
 |    IF RELATION = 99 THEN RELATION = .B;
 |
 | FORMAT:  associates the formats created by the PROC FORMAT step with
 | the variables named in the INPUT statement.
 |
 | NOTE:  Users should modify this setup file to suit their specific needs.
 | Sections for PROC FORMAT, FORMAT, and MISSING VALUE RECODES have been
 | commented out (i.e., '/*'). To include these sections in the final SAS
 | setup, users should remove the SAS comment indicators from the desired
 | section(s).
 |
 |------------------------------------------------------------------------*/

* SAS PROC FORMAT;

/*
PROC FORMAT;
  VALUE cigmorls  1='(1) More' 2='(2) Less' 3='(3) Same' 4='(4) No opinion'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cigtry    91='(91) NEVER SMOKED CIGARETTES' 94='(94) DONT KNOW' ;
  VALUE cig5pk    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE cigrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER SMOKED CIGARETTES' 94='(94) DONT KNOW' ;
  VALUE avcig     1='(1) Less than 1' 2='(2) 1 - 5' 3='(3) Half pack' 4='(4) Pack'
                  5='(5) 1 1/2 packs' 6='(6) Two plus' 91='(91) NEVER SMOKED CIGARETTES'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE morlsmj   1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlssed  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlstrn  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlsamp  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlscoc  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlslsd  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE morlsher  1='(1) More' 2='(2) Fewer' 3='(3) Other' 98='(98) BLANK (NO ANSWER)' ;
  VALUE addalc    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addmj     1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addsed    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addtran   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addamp    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addcoc    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addlsd    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addher    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE addnone   1='(1) Nothing circled above' 2='(2) 1 or more drugs circled' ;
  VALUE alctry    81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' ;
  VALUE alcrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but more than mth ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ALCOHOL' ;
  VALUE alcdays   81='(81) NEVER USED ALCOHOL Logically imputed'
                  91='(91) NEVER USED ALCOHOL'
                  93='(93) DID NOT USE ALCOHOL IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE alcpref   1='(1) Beer' 2='(2) Wine' 3='(3) Liquor'
                  4='(4) Combination of these/it varies'
                  81='(81) NEVER USED ALCOHOL Logically assigned'
                  91='(91) NEVER USED ALCOHOL' 94='(94) DONT KNOW' ;
  VALUE mjknew    91='(91) NEVER KNEW ANYONE WHO TRIED MARIJUANA' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjopp     91='(91) NEVER HAD A CHANCE TO TRY MARIJUANA' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE mjage     91='(91) NEVER USED MARIJUANA' 94='(94) DONT KNOW' ;
  VALUE mjtot     1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DONT KNOW' ;
  VALUE mjrec     1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but more than mth ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED MARIJUANA' ;
  VALUE mjday30a  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mjav30a   1='(1) Less than 1 a day' 2='(2) 1 a day' 3='(3) 2-3 a day'
                  4='(4) 4-6 a day' 5='(5) 7-10 a day' 6='(6) 11 or more a day'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT USE MARIJUANA IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' ;
  VALUE mjevermt  1='(1) Yes' 2='(2) No' 91='(91) NEVER USED MARIJUANA' 94='(94) DONT KNOW' ;
  VALUE mjaloft   1='(1) Usually' 2='(2) About half the time' 3='(3) Occasionally'
                  4='(4) Rarely' 5='(5) Never' 91='(91) NEVER USED MARIJUANA'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE rxbutsol  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxbutcap  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxamytal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxeskab   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxlumnal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmebral  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxamobar  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxphnbar  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxalurat  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxplacid  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdorden  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxnoldar  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsopor   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxquaal   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxparest  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxnoctec  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmthqua  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxchhyd   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxnemtal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxcarbr   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsecnal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtuinal  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxpentob  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsecob   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdalman  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsedoth  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxseddk   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE sedbor    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE sedbor3f  1='(1) Within the past month' 2='(2) More than a month ago'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxnosed   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsedage  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxsedrec  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rxsed15d  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE quaalude  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE seconal   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE tuinal    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE placidyl  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE sopor     1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE nembutal  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE sednewa   0='(0) No other' 1='(1) Butisol' 2='(2) Buticaps' 3='(3) Amytal'
                  4='(4) Eskabarb' 6='(6) Mebaral' 8='(8) Phenobarbital' 11='(11) Doriden'
                  12='(12) Noludar' 15='(15) Parest' 16='(16) Noctec' 17='(17) Methaqualone'
                  18='(18) Chloral hydrate' 20='(20) Carbrital' 23='(23) Pentobarbital'
                  25='(25) Dalmane' 91='(91) NEVER USED SEDATIVES' 94='(94) DONT KNOW' ;
  VALUE sednewb   0='(0) No other' 1='(1) Butisol' 6='(6) Mebaral' 7='(7) Amobarbital'
                  11='(11) Doriden' 15='(15) Parest' 17='(17) Methaqualone'
                  23='(23) Pentobarbital' 25='(25) Dalmane' 91='(91) NEVER USED SEDATIVES' ;
  VALUE nosedat   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE quaa30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE seco30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE tuin30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE plac30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE sopo30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE nemb30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE sednwa3f  0='(0) No other' 4='(4) Eskabarb' 11='(11) Doriden' 17='(17) Methaqualone'
                  25='(25) Dalmane' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' ;
  VALUE sednwb3f  0='(0) No other' 91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY' ;
  VALUE nosed30f  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED SEDATIVES' 94='(94) DONT KNOW' ;
  VALUE sedage    91='(91) NEVER USED SEDATIVES' 94='(94) DONT KNOW' ;
  VALUE sedtot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but over 30 days ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED SEDATIVES' ;
  VALUE seddays   91='(91) NEVER USED SEDATIVES'
                  93='(93) DID NOT USE SEDATIVES IN THE PAST 30 DAY'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE sedrx     1='(1) Prescribed by doctor for me at least once'
                  2='(2) Always got them some other way'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedmjocc  1='(1) Yes' 2='(2) No, never on the same occasion'
                  3='(3) Never tried marijuana' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedmore   1='(1) Yes, I needed more pills' 2='(2) No'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedstop   1='(1) Yes' 2='(2) No, never had trouble/never tried to cut'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE sedhelp   1='(1) Yes' 2='(2) No, never got help/never needed help'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED SEDATIVES'
                  94='(94) DONT KNOW' ;
  VALUE rxvalium  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxlibrum  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxlibtab  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxskly    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxserax   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtranx   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxativan  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxverst   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmepros  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmiltwn  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxeqnil   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmeprob  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxvistar  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxatarax  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxbndryl  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtrnoth  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtrndk   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE trnbor    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE trnbor3f  1='(1) Within the past month' 2='(2) More than a month ago'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxnotran  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtrnage  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxtrnrec  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rxtrn15d  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE trnread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE valium    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE librium   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE benadryl  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE tranxene  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE equanil   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE libritab  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE trnewa    0='(0) No other' 4='(4) Sk-lygen' 5='(5) Serax' 7='(7) Ativan' 8='(8) Verstran'
                  10='(10) Miltown' 12='(12) Meprobamate' 13='(13) Vistaril' 14='(14) Atarax'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnewb    0='(0) No other' 5='(5) Serax' 7='(7) Ativan' 14='(14) Atarax'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE notranq   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE valm30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE lbrm30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE bena30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE trnx30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE eqnl30dy  2='(2) Checkmark not made'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE lbtb30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE trnewa3f  0='(0) No other' 4='(4) Sk-lygen' 7='(7) Ativan' 14='(14) Atarax'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30'
                  94='(94) DONT KNOW' ;
  VALUE trnewb3f  0='(0) No other' 91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE notran3f  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE tranage   91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trantot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED TRANQUILIZERS'
                  94='(94) DONT KNOW' ;
  VALUE tranrec   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but over 30 days ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED TRANQUILIZERS' ;
  VALUE trandays  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE trnrx     1='(1) Prescribed by a doctor for me at least once'
                  2='(2) Always got them some other way'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnmjocc  1='(1) Yes' 2='(2) No, never on the same occasion'
                  3='(3) Never tried marijuana' 91='(91) NEVER USED TRANQUILIZERS'
                  94='(94) DONT KNOW' ;
  VALUE trnmore   1='(1) Yes, I needed more pills' 2='(2) No'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnstop   1='(1) Yes' 2='(2) No, never had trouble/never tried to cut'
                  85='(85) BAD DATA Logically assigned'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnhelp   1='(1) Yes' 2='(2) No, never got help/never needed help'
                  91='(91) NEVER USED TRANQUILIZERS' 94='(94) DONT KNOW' ;
  VALUE trnmark   1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxdexed   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdexam   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxeskat   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxbenz    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxbiphet  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdesox   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdetamp  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmethed  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxobla    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtenuat  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtepan   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdidrex  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxplegin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxprelud  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxpresat  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxinamin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxponmin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxvornil  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsanrex  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxritlin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxcylert  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxstmoth  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxstmdk   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE stmbor    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE stmbor3f  1='(1) Within the past month' 2='(2) More than a month ago'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxnostm   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxstmage  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxstmrec  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rxstm15d  1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE stmread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE dexed     1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE benz      1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE biphet    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE dexamyl   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE desoxyn   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE preludin  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE stimnewa  0='(0) No other' 3='(3) Eskatrol' 7='(7) Dextroamphetamine'
                  8='(8) Methedrine' 9='(9) Obedrin-l.a.' 10='(10) Tenuate' 12='(12) Didrex'
                  13='(13) Plegine' 15='(15) Pre-sate' 16='(16) Ionamin' 18='(18) Voranil'
                  19='(19) Sanorex' 20='(20) Ritalin' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stimnewb  0='(0) No other' 3='(3) Eskatrol' 8='(8) Methedrine' 10='(10) Tenuate'
                  11='(11) Tepanil' 16='(16) Ionamin' 19='(19) Sanorex' 20='(20) Ritalin'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE nostims   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE dxdr30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE bndr30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED TRANQUILIZERS'
                  93='(93) DID NOT USE TRANQUILIZERS IN THE PAST 30' ;
  VALUE bpht30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE dxml30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE dsox30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE prel30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE stmnwa3f  0='(0) No other' 8='(8) Methedrine' 10='(10) Tenuate' 12='(12) Didrex'
                  16='(16) Ionamin' 20='(20) Ritalin' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA'
                  94='(94) DONT KNOW' ;
  VALUE stmnwb3f  0='(0) No other' 91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA' ;
  VALUE nostim3f  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED STIMULANTS' 94='(94) DONT KNOW' ;
  VALUE stimage   91='(91) NEVER USED STIMULANTS' 94='(94) DONT KNOW' ;
  VALUE stimtot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stimrec   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but over 30 days ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED STIMULANTS' ;
  VALUE stimdays  91='(91) NEVER USED STIMULANTS'
                  93='(93) DID NOT USE STIMULANTS IN THE PAST 30 DA'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE stimrx    1='(1) Prescribed by a doctor for me at least once'
                  2='(2) Always got them some other way'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stmmjocc  1='(1) Yes' 2='(2) No, never on the same occasion'
                  3='(3) Never tried marijuana' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stmmore   1='(1) Yes, I needed more pills' 2='(2) No'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stmstop   1='(1) Yes' 2='(2) No, never had trouble/never tried to cut'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED STIMULANTS'
                  94='(94) DONT KNOW' ;
  VALUE stmhelp   1='(1) Yes' 2='(2) No, never got help/never needed help'
                  91='(91) NEVER USED STIMULANTS' 94='(94) DONT KNOW' ;
  VALUE rxdarvon  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdolene  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxsk65ff  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxpropox  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxleritn  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxlevodr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxpercod  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdemrol  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdilaud  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtylcod  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxcodene  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxdoloph  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxwestod  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxmethad  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxtalwin  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxanloth  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxanldk   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE anlbor    1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE anlbor3f  1='(1) Within the past month' 2='(2) More than a month ago'
                  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxnoanl   1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE rxanlage  94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE rxanlrec  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE rxanl15d  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE anlread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE darvon    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE percodan  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE demerol   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE dilaud    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE tylcod    1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE codeine   1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE analnewa  0='(0) No other' 2='(2) Dolene' 3='(3) Sk-65' 4='(4) Propoxyphene'
                  5='(5) Leritine' 12='(12) Dolophine' 14='(14) Methadone' 15='(15) Talwin'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE analnewb  0='(0) No other' 2='(2) Dolene' 3='(3) Sk-65' 5='(5) Leritine'
                  13='(13) Westodone' 91='(91) NEVER USED ANALGESICS' ;
  VALUE analnone  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE darv30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE perc30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE deme30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE dlau30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE tcod30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE cdne30dy  1='(1) Checkmark made' 2='(2) Checkmark not made'
                  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE anlnwa3f  0='(0) No other' 91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA'
                  94='(94) DONT KNOW' ;
  VALUE anlnwb3f  0='(0) No other' 3='(3) Sk-65' 91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA' ;
  VALUE analno3f  1='(1) Response circled' 2='(2) Response not circled'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE analage   91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE analtot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' ;
  VALUE analrec   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months (but over 30 days ago)'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED ANALGESICS' ;
  VALUE analdays  91='(91) NEVER USED ANALGESICS'
                  93='(93) DID NOT USE ANALGESICS IN THE PAST 30 DA'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE analrx    1='(1) Prescribed by a doctor for me at least once'
                  2='(2) Always got them some other way'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' ;
  VALUE anlmjocc  1='(1) Yes' 2='(2) No, never on the same occasion'
                  3='(3) Never tried marijuana' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' ;
  VALUE analmore  1='(1) Yes, I needed more pills' 2='(2) No'
                  85='(85) BAD DATA Logically assigned' 91='(91) NEVER USED ANALGESICS'
                  94='(94) DONT KNOW' ;
  VALUE analstop  1='(1) Yes' 2='(2) No, never had trouble/never tried to cut'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE analhelp  1='(1) Yes' 2='(2) No, never got help/never needed help'
                  91='(91) NEVER USED ANALGESICS' 94='(94) DONT KNOW' ;
  VALUE cocknew   91='(91) NEVER KNEW ANYONE WHO TRIED COCAINE' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocopp    91='(91) NEVER HAD A CHANCE TO TRY COCAINE' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocage    91='(91) NEVER USED COCAINE' 94='(94) DONT KNOW' ;
  VALUE coctot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED COCAINE'
                  94='(94) DONT KNOW' ;
  VALUE cocrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED COCAINE' ;
  VALUE cocus30a  91='(91) NEVER USED COCAINE'
                  93='(93) DID NOT USE COCAINE IN THE PAST 30 DAYS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE cocmjoft  1='(1) Nearly every time' 2='(2) About half the time'
                  3='(3) Occasionally' 4='(4) Rarely' 5='(5) Never'
                  91='(91) NEVER USED COCAINE' 94='(94) DONT KNOW' ;
  VALUE halread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE hallknew  91='(91) NEVER KNEW ANYONE WHO TRIED HALLUCINOGEN'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE hallopp   91='(91) NEVER HAD A CHANCE TO TRY HALLUCINOGENS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hallage   91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' ;
  VALUE halltot   1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED HALLUCINOGENS'
                  94='(94) DONT KNOW' ;
  VALUE hallrec   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HALLUCINOGENS' ;
  VALUE hal30use  91='(91) NEVER USED HALLUCINOGENS'
                  93='(93) DID NOT USE HALLUCINOGENS IN THE PAST 30'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE halmjoft  1='(1) Nearly every time' 2='(2) About half the time'
                  3='(3) Occasionally' 4='(4) Rarely' 5='(5) Never'
                  91='(91) NEVER USED HALLUCINOGENS' 94='(94) DONT KNOW' ;
  VALUE pcp       1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' ;
  VALUE pcprec    1='(1) Within the past month (30 days)'
                  2='(2) More than a month ago' 91='(91) NEVER USED PCP'
                  94='(94) DONT KNOW' ;
  VALUE unstahal  1='(1) Yes' 2='(2) No/not sure' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE secndoth  1='(1) Pills' 2='(2) Cocaine' 3='(3) LSD, PCP, or other hallucinogen'
                  4='(4) Other drug' 5='(5) Never tried any drug except marijuana'
                  6='(6) Marijuana was not the first one I tried'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT RECEIVE THIS ANSWER SHEET' 94='(94) DONT KNOW' ;
  VALUE secndmjr  1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times'
                  5='(5) Never tried any drug except marijuana'
                  6='(6) Marijuana was not the first one I tried'
                  91='(91) NEVER USED MARIJUANA'
                  93='(93) DID NOT RECEIVE THIS ANSWER SHEET' 94='(94) DONT KNOW' ;
  VALUE herread   1='(1) Interviewer' 2='(2) Self' 99='(99) LEGITIMATE SKIP' ;
  VALUE herknew   91='(91) NEVER KNEW ANYONE WHO TRIED HEROIN' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE heropp    91='(91) NEVER HAD A CHANCE TO TRY HEROIN' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herage    91='(91) NEVER USED HEROIN' 94='(94) DONT KNOW' ;
  VALUE hertot    1='(1) 1 or 2 times' 2='(2) 3 to 10 times' 3='(3) 11 to 99 times'
                  4='(4) 100 or more times' 91='(91) NEVER USED HEROIN' 94='(94) DONT KNOW' ;
  VALUE herrec    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago'
                  8='(8) Use in past year LOGICALLY IMPUTED'
                  9='(9) Use in lifetime LOGICALLY IMPUTED'
                  91='(91) NEVER USED HEROIN' ;
  VALUE her30use  91='(91) NEVER USED HEROIN'
                  93='(93) DID NOT USE HEROIN IN THE PAST 30 DAYS'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE herneedl  1='(1) Yes' 2='(2) No' 91='(91) NEVER USED HEROIN' ;
  VALUE fyrmjtry  1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' ;
  VALUE fyrplmtr  1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' ;
  VALUE fyrplntr  1='(1) Response circled' 2='(2) Response not circled'
                  94='(94) DONT KNOW' ;
  VALUE fyrcoctr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE fyrhaltr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE fyrhertr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE fyrnontr  1='(1) Response circled' 2='(2) Response not circled' ;
  VALUE mj30buy   0='(0) None' 1='(1) 1/2 ounce or less' 2='(2) About 3/4 ounce'
                  3='(3) About 1 ounce' 4='(4) About 2 ounces' 5='(5) About 3 ounces'
                  6='(6) About 4 ounces' 7='(7) About 1/2 pound' 8='(8) Other'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE mj30lbs   98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE mjbuck    9994='(9994) DONT KNOW' 9998='(9998) BLANK (NO ANSWER)' ;
  VALUE effdeprs  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effargum  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effacdnt  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effschl   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE effwork   1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE odhelp    1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE closfrns  0='(0) No close friends living in regular house'
                  90='(90) 90 or more' 93='(93) NOT ASKED THESE QUESTIONS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE frnsher   0='(0) No close friends living in reg household'
                  93='(93) NOT ASKED THESE QUESTIONS' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE frnsex    1='(1) Male' 2='(2) Female' 93='(93) NOT ASKED THESE QUESTIONS'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE frnage    1='(1) 12-17' 2='(2) 18-25' 3='(3) 26-34' 4='(4) 35+'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE frntryh   1='(1) Within the past month (30 days)'
                  2='(2) Within the past year' 3='(3) More than a year ago'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE frnrech   1='(1) Within the past month (30 days)'
                  2='(2) Within the past year' 3='(3) More than a year ago'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE knowuseh  1='(1) Certain' 2='(2) Probable' 3='(3) Not probable'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE othknow   0='(0) No other close friends living in reg hh'
                  93='(93) NOT ASKED THESE QUESTIONS' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE instate   98='(98) BLANK (NO ANSWER)' ;
  VALUE instatef  1='(1) Less than one year' 2='(2) All my life'
                  3='(3) On and off/moved in and moved out' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE ethrace   1='(1) American Indian or Alaskan Native'
                  2='(2) Asian or Pacific Islander' 3='(3) Black' 4='(4) Hispanic'
                  5='(5) White' 6='(6) Black & Hispanic' 7='(7) Other'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE hisp      1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  7='(7) Combination' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE sex       1='(1) Male' 2='(2) Female' ;
  VALUE respage   97='(97) 97 plus' ;
  VALUE ragegrp   1='(1) 18-34' 2='(2) 35+'
                  3='(3) No interview to be completed in household'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE enrlcoll  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE typeschl  1='(1) College' 2='(2) Community college' 3='(3) Vocational'
                  4='(4) Adult school' 5='(5) High school' 6='(6) Other'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE stdftpt   1='(1) Full-time' 2='(2) Part-time' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE educ      1='(1) No schooling' 2='(2) Elementary school -- 8th grade or less'
                  3='(3) Some high school' 4='(4) High school graduate'
                  5='(5) Vocational/technical school beyond high school'
                  6='(6) Some college' 7='(7) College graduate or beyond'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE veteran   1='(1) Yes, a veteran (includes reserves)'
                  2='(2) Yes, a current member on active duty' 3='(3) No, neither'
                  4='(4) Yes, non-U S veteran' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE marital   1='(1) Married' 2='(2) Living as a couple' 3='(3) Widowed'
                  4='(4) Divorced or separated' 5='(5) Never married'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE employ3f  1='(1) Yes' 2='(2) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE occupat   1='(1) Laborer' 2='(2) Service workers'
                  3='(3) Operative or similar work'
                  4='(4) Craftsman, foreman, skilled worker'
                  5='(5) Retail or office worker' 6='(6) Manager or similar'
                  7='(7) Business executive or professional' 8='(8) Other'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE nolabor   1='(1) Housewife' 2='(2) Student' 3='(3) Unemployed' 4='(4) Retired'
                  5='(5) Disabled' 6='(6) Other' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE totpeop   1='(1) Only myself' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE children  1='(1) Yes' 2='(2) No' 94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE ageun12f  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE age1217f  99='(99) LEGITIMATE SKIP' ;
  VALUE age18ovr  99='(99) LEGITIMATE SKIP' ;
  VALUE hhspous   1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE numparen  99='(99) LEGITIMATE SKIP' ;
  VALUE numsibln  7='(7) 7 or more' 99='(99) LEGITIMATE SKIP' ;
  VALUE numotrel  99='(99) LEGITIMATE SKIP' ;
  VALUE numfrnds  99='(99) LEGITIMATE SKIP' ;
  VALUE numotper  99='(99) LEGITIMATE SKIP' ;
  VALUE numtot    94='(94) DONT KNOW' 99='(99) LEGITIMATE SKIP' ;
  VALUE cwe       1='(1) Yes' 2='(2) No, respondent is chief'
                  3='(3) No wage earner in this household'
                  4='(4) Two or more equal wage earners' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE cweocc    1='(1) Laborer' 2='(2) Service worker'
                  3='(3) Operative or similar work'
                  4='(4) Craftsman, foreman, skilled worker'
                  5='(5) Retail or office worker' 6='(6) Manager or similar'
                  7='(7) Business executive or professional' 8='(8) Other'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE military  1='(1) Yes, an active member lives here'
                  2='(2) Yes, an immediate family member is elsewhere' 4='(4) No'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE income    1='(1) No income' 2='(2) Under $10,000' 3='(3) $10,00-19,999'
                  4='(4) $20,000-29,999' 5='(5) $30,000-39,999' 6='(6) $40,000-49,999'
                  7='(7) $50,000 plus' 94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ytheduc   1='(1) Seventh grade or less' 2='(2) Eighth grade' 3='(3) Ninth grade'
                  4='(4) Tenth grade' 5='(5) Eleventh grade' 6='(6) Twelfth grade'
                  7='(7) Beyond high school' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ythstud   1='(1) Yes' 2='(2) No' 99='(99) LEGITIMATE SKIP' ;
  VALUE ystdftpt  1='(1) Full-time' 2='(2) Part-time' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE hmwrkhrs  1='(1) None' 2='(2) 5 hours or less (per week)' 3='(3) 6 to 10 hours'
                  4='(4) 11 to 20 hours' 5='(5) More than 20 hours' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE jobhours  1='(1) None' 2='(2) 5 hours or less (per week)' 3='(3) 6 to 10 hours'
                  4='(4) 11 to 20 hours' 5='(5) More than 20 hours' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE funhours  1='(1) Less than once a week' 2='(2) About once a week'
                  3='(3) Two to three times a week'
                  4='(4) Four to five times a weeks'
                  5='(5) Every night or almost every night' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE datetims  1='(1) Never' 2='(2) Once a month or less'
                  3='(3) Two to three times a month' 4='(4) About once a week'
                  5='(5) Two to three times a week' 6='(6) Four or more times a week'
                  94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ytotpeop  99='(99) LEGITIMATE SKIP' ;
  VALUE numysibs  7='(7) 7 or more' 99='(99) LEGITIMATE SKIP' ;
  VALUE numosibs  7='(7) 7 or more' 99='(99) LEGITIMATE SKIP' ;
  VALUE mother    99='(99) LEGITIMATE SKIP' ;
  VALUE father    99='(99) LEGITIMATE SKIP' ;
  VALUE ythotrel  99='(99) LEGITIMATE SKIP' ;
  VALUE ythotper  7='(7) 7 or more' 99='(99) LEGITIMATE SKIP' ;
  VALUE ynumtot   99='(99) LEGITIMATE SKIP' ;
  VALUE othsibs   1='(1) Yes' 2='(2) No' 3='(3) Step-siblings' 98='(98) BLANK (NO ANSWER)'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE ythcwe3f  1='(1) Yes' 2='(2) No' 3='(3) No chief wage earner'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ythoccup  1='(1) Laborer' 2='(2) Service worker'
                  3='(3) Operative or similar work'
                  4='(4) Craftsman, foreman, skilled worker'
                  5='(5) Retail or office worker' 6='(6) Manager or similar'
                  7='(7) Business executive or professional' 8='(8) Other'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ynolabor  1='(1) Housewife' 2='(2) Student' 3='(3) Unemployed' 4='(4) Retired'
                  5='(5) Disabled' 6='(6) Other' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE ythmltry  1='(1) Yes, an active member lives here'
                  2='(2) Yes, an immediate family member elsewhere' 3='(3) Both'
                  4='(4) No' 98='(98) BLANK (NO ANSWER)' 99='(99) LEGITIMATE SKIP' ;
  VALUE intmo     1='(1) November' 2='(2) December' 3='(3) March' 4='(4) April' 5='(5) May'
                  6='(6) June' 7='(7) July' 9='(9) February' 94='(94) DONT KNOW' ;
  VALUE intda     94='(94) DONT KNOW' ;
  VALUE hharea    1='(1) City' 2='(2) Town' 3='(3) Suburbs' 4='(4) Village' 5='(5) Rural'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE undint    1='(1) No difficulty -- No language or reading problem'
                  2='(2) Just a little difficulty -- Almost no lang prob'
                  3='(3) A fair amount of difficulty -- Some lang/read prob'
                  4='(4) A lot of difficulty -- Considerable lang/read prob'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE coopint   1='(1) Very' 2='(2) Fairly' 3='(3) Not very' 4='(4) Hostile'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE estrace   1='(1) Black' 2='(2) White' 3='(3) Other' 94='(94) DONT KNOW'
                  98='(98) BLANK (NO ANSWER)' ;
  VALUE privacy   1='(1) Completely private'
                  3='(3) Minor distractions by parent/older person'
                  5='(5) Parent/older person in room 1/3 of time'
                  7='(7) Serious interruptions more than 1/2 of time'
                  9='(9) Constant presence of parent/older person' 94='(94) DONT KNOW'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE quextype  1='(1) Core' 2='(2) Form N' ;
  VALUE adultyth  1='(1) Adult' 2='(2) Youth' ;
  VALUE adltqcd   1='(1) Core' 2='(2) Form N' ;
  VALUE tothhvis  94='(94) DONT KNOW' ;
  VALUE finlresf  0='(0) Respondent not at home' 1='(1) Completed interview'
                  4='(4) Instruction is do not interview'
                  8='(8) No record; face sheet not returned'
                  9='(9) Respondent refused' 94='(94) DONT KNOW' 97='(97) REFUSED' ;
  VALUE vsadltcm  0='(0) No adult interview' 94='(94) DONT KNOW' ;
  VALUE phadltcm  0='(0) No adult interview' 1='(1) Original assignment'
                  2='(2) Reassignment' 94='(94) DONT KNOW' ;
  VALUE vsythcm   94='(94) DONT KNOW' 98='(98) BLANK (NO ANSWER)' ;
  VALUE phythcm   0='(0) Interview not complete' 1='(1) Original assignment'
                  2='(2) Reassignment' 94='(94) DONT KNOW' ;
  VALUE division  1='(1) North East (New England)'
                  2='(2) North East (Middle Atlantic)'
                  3='(3) North Central (East North Central)'
                  4='(4) North Central (West North Central)'
                  5='(5) South (South Atlantic)' 6='(6) South (East South Central)'
                  7='(7) South (West South Central)' 8='(8) West (Mountain)'
                  9='(9) West (Pacific)' ;
  VALUE region    1='(1) Northeast' 2='(2) North Central' 3='(3) South' 4='(4) West' ;
  VALUE popdenx   1='(1) Segment in a self-representing SMSA'
                  2='(2) Segment in a non-self-representing SMSA'
                  3='(3) Segment not in a SMSA' ;
  VALUE iiage     1='(1) Age from source file' ;
  VALUE irsex     1='(1) Male' 2='(2) Female' ;
  VALUE iisex     1='(1) Sex from source file' ;
  VALUE irracex   1='(1) American Indian or Alaskan native'
                  2='(2) Asian or Pacific Islander' 3='(3) Black' 4='(4) White'
                  5='(5) Hispanic' ;
  VALUE iiracex   1='(1) Race from source file' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' ;
  VALUE irhoind   1='(1) Hispanic' 2='(2) Non-Hispanic' ;
  VALUE iihoind   1='(1) Hispanicity from source file' ;
  VALUE irhogrp   1='(1) Puerto Rican' 2='(2) Mexican' 3='(3) Cuban' 4='(4) Other'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iihogrp   1='(1) Hispanic-Origin Group from source file'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE irmarit   1='(1) Married' 2='(2) Widowed' 3='(3) Divorced or separated'
                  4='(4) Never married' 5='(5) Cohabitating' 99='(99) LEGITIMATE SKIP' ;
  VALUE iimarit   1='(1) Marital status from source file'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE ireduc    1='(1) No schooling' 2='(2) Less than 8th grade'
                  3='(3) Some high school' 4='(4) High school graduate'
                  5='(5) Vocational/technical school' 6='(6) Some college'
                  7='(7) College graduate/Some graduate school'
                  99='(99) LEGITIMATE SKIP' ;
  VALUE iieduc    1='(1) Education from source file' 2='(2) Logically imputed data'
                  3='(3) Statistically imputed data' 9='(9) LEGITIMATE SKIP' ;
  VALUE iralcrc   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but more than a month ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used alcohol' ;
  VALUE iialcrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irmjrc    1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but more than a month ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used marijuana' ;
  VALUE iimjrc    1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircocrc   1='(1) Within the past months (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 9='(9) Never used cocaine' ;
  VALUE iicocrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irsedrc   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but over 30 days ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used sedatives' ;
  VALUE iisedrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irtranrc  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but over 30 days ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used tranquilizers' ;
  VALUE iitranrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irstimrc  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but over 30 days ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used stimulants' ;
  VALUE iistimrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE iranalrc  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months but over 30 days ago'
                  3='(3) Six months to a year ago' 4='(4) More than a year ago'
                  9='(9) Never used analgesics' ;
  VALUE iianalrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE ircigrc   1='(1) In the past 30 days' 2='(2) Within the past six months'
                  3='(3) Within the past year' 4='(4) More than a year ago'
                  9='(9) Never smoked cigarettes' ;
  VALUE iicigrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irhallrc  1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 9='(9) Never used hallucinogens' ;
  VALUE iihallrc  1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irherrc   1='(1) Within the past month (30 days)'
                  2='(2) Within the past six months' 3='(3) Six months to a year ago'
                  4='(4) More than a year ago' 9='(9) Never used heroin' ;
  VALUE iiherrc   1='(1) Questionnaire data' 3='(3) Statistically imputed data' ;
  VALUE irpcprc   1='(1) Within the past month (30 days)' 2='(2) More than month ago'
                  9='(9) Never used PCP' ;
  VALUE iipcprc   1='(1) Questionnaire data' ;
  VALUE catage    1='(1) 12-17 years old' 2='(2) 18-25 years old' 3='(3) 26-34 years old'
                  4='(4) 35+ years old' ;
  VALUE catag2ff  1='(1) 12-17 years old' 2='(2) 18-25 years old' 3='(3) 26+ years old' ;
  VALUE catag3ff  1='(1) 12-17 years old' 2='(2) 18-25 years old' 3='(3) 26-34 years old'
                  4='(4) 35-49 years old' 5='(5) 50+ years old' ;
  VALUE race      1='(1) White (IRRACE = 5 and IRHOIND = 2)'
                  2='(2) Black (IRRACE = 6 and IRHOIND = 2)'
                  3='(3) Hispanic (IRHOIND = 1)'
                  4='(4) Other (IRRACE = 1-4 and IRHOIND = 2)' ;
  VALUE hisprace  1='(1) Hispanic' 2='(2) Non-Hispanic Black'
                  3='(3) Non-Hispanic Non-Black' ;
  VALUE educcatf  1='(1) Less than high school (IREDUC=1-3 and IRAGE=>18'
                  2='(2) High school graduate (IREDUC = 4 and IRAGE=>18'
                  3='(3) Some college/postsec (IREDUC=5-6 and IRAGE=>18'
                  4='(4) College graduate (IREDUC = 7 and IRAGE=>18'
                  5='(5) 12-17 years old (IRAGE = 12-17)' ;
  VALUE halflag   0='(0) Never used (IRHALRC = 9)' 1='(1) Ever used (IRHALRC = 1-4)' ;
  VALUE halyr     0='(0) Did not use in the past year (IRHALRC = 4,9)'
                  1='(1) Used within the past year (IRHALRC = 1-3' ;
  VALUE halmon    0='(0) Did not use in the past month (IRHALRC = 2-4, 9)'
                  1='(1) Used within the past month (IRHALRC = 1)' ;
  VALUE pcpflag   0='(0) Never used (IRPCPRC = 9)' 1='(1) Ever used (IRPCPRC = 1-2)' ;
  VALUE pcpyrx    0='(0) Did not use in the past year (IRPCPRC = 2, 9)'
                  1='(1) Used within the past year (IRPCPRC = 1)' ;
  VALUE pcpmon    0='(0) Did not use in the past month (IRPCPRC = 2, 9)'
                  1='(1) Used within the past month (IRPCPRC = 1)' ;
  VALUE stmflag   0='(0) Never used (IRSTMRC = 9)' 1='(1) Ever used (IRSTMRC = 1-4)' ;
  VALUE stmyr     0='(0) Did not use in the past year (IRSTMRC = 4, 9)'
                  1='(1) Used within the past year (IRSTMRC = 1-3' ;
  VALUE stmmon    0='(0) Did not use in the past month (IRSTMRC = 2-4, 9)'
                  1='(1) Used within the past month (IRSTMRC = 1)' ;
  VALUE sedflag   0='(0) Never used (IRSEDRC = 9)' 1='(1) Ever used (IRSEDRC = 1-4)' ;
  VALUE sedyr     0='(0) Did not use in the past year (IRSEDRC = 4, 9)'
                  1='(1) Used within the past year (IRSEDRC = 1-3' ;
  VALUE sedmon    0='(0) Did not use in the past month (IRSEDRC = 2-4, 9)'
                  1='(1) Used within the past month (IRSEDRC = 1)' ;
  VALUE trqflag   0='(0) Never used (IRTRNRC = 9)' 1='(1) Ever used (IRTRNRC = 1-4)' ;
  VALUE trqyr     0='(0) Did not use in the past year (IRTRNRC = 4, 9)'
                  1='(1) Used within the past year (IRTRNRC = 1-3' ;
  VALUE trqmon    0='(0) Did not use in the past month (IRTRNRC = 2-4, 9)'
                  1='(1) Used within the past month (IRTRNRC = 1)' ;
  VALUE anlflag   0='(0) Never used (IRANLRC = 9)' 1='(1) Ever used (IRANLRC = 1-4)' ;
  VALUE anlyr     0='(0) Did not use in the past year (IRANLRC = 4, 9)'
                  1='(1) Used within the past year (IRANLRC = 1-3' ;
  VALUE anlmon    0='(0) Did not use in the past month (IRANLRC = 2-4, 9)'
                  1='(1) Used within the past month (IRANLRC = 1)' ;
  VALUE alcflag   0='(0) Never used (IRALCRC = 9)' 1='(1) Ever used (IRALCRC = 1-4)' ;
  VALUE alcyr     0='(0) Did not use in the past year (IRALCRC = 4, 9)'
                  1='(1) Used within the past year (IRALCRC = 1-3' ;
  VALUE alcmon    0='(0) Did not use in the past month (IRALCRC = 2-4, 9)'
                  1='(1) Used within the past month (IRALCRC = 1)' ;
  VALUE cigflag   0='(0) Never used (IRCIGRC = 9)' 1='(1) Ever used (IRCIGRC = 1-4)' ;
  VALUE cigyr     0='(0) Did not use in the past year (IRCIGRC = 4, 9)'
                  1='(1) Used within the past year (IRCIGRC = 1-3' ;
  VALUE cigmon    0='(0) Did not use in the past month (IRCIGRC = 2-4, 9)'
                  1='(1) Used within the past month (IRCIGRC = 1)' ;
  VALUE herflag   0='(0) Never used (IRHERRC = 9)' 1='(1) Ever used (IRHERRC = 1-4)' ;
  VALUE heryr     0='(0) Did not use in the past year (IRHERRC = 4, 9)'
                  1='(1) Used within the past year (IRHERRC = 1-3' ;
  VALUE hermon    0='(0) Did not use in the past month (IRHERRC = 2-4, 9)'
                  1='(1) Used within the past month (IRHERRC = 1)' ;
  VALUE mrjflag   0='(0) Never used (IRMJRC = 9)' 1='(1) Ever used (IRMJRC = 1-4)' ;
  VALUE mrjyr     0='(0) Did not use in the past year (IRMJRC = 4, 9)'
                  1='(1) Used within the past year (IRMJRC = 1-3)' ;
  VALUE mrjmon    0='(0) Did not use in the past month (IRMJRC = 2-4, 9)'
                  1='(1) Used within the past month (IRMJRC = 1)' ;
  VALUE cocflag   0='(0) Never used (IRCOCRC = 9)' 1='(1) Ever used (IRCOCRC = 1-4)' ;
  VALUE cocyr     0='(0) Did not use in the past year (IRCOCRC = 4, 9)'
                  1='(1) Used within the past year (IRCOCRC = 1-3' ;
  VALUE cocmon    0='(0) Did not use in the past month (IRCOCRC = 2-4, 9)'
                  1='(1) Used within the past month (IRCOCRC = 1)' ;
  VALUE psyflagf  0='(0) Never used (ALL SOURCE VARIABLES = 9)'
                  1='(1) Ever used (ANY SOURCE VARIABLE < 9)' ;
  VALUE psyyr2ff  0='(0) Did not use within past year (ALL SOURCE > 3)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE < 4)' ;
  VALUE psymon2f  0='(0) Did not use in past month (ALL SOURCE VARS > 1)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumflagx  0='(0) Never used (ALL SOURCE VARIABLES = 0)'
                  1='(1) Ever used (ANY SOURCE VARIABLE = 1)' ;
  VALUE sumyrx    0='(0) Did not use in past year (ALL SOURCE VARS = 0)'
                  1='(1) Used in past year (ANY SOURCE VARIABLE = 1)' ;
  VALUE summonx   0='(0) Did not use in past month (ALL SOURCE VARS = 0)'
                  1='(1) Used in past month (ANY SOURCE VARIABLE = 1)' ;
  VALUE mjoflagx  0='(0) Never used MJ/has used both MJ & anothr illct drug'
                  1='(1) Marijuana is only (illicit) drug ever used' ;
  VALUE mjoyr2x   0='(0) MJ not used past yr/Used MJ & othr drug past yr'
                  1='(1) Marijuana is only (illicit) drug in past year' ;
  VALUE mjomon2x  0='(0) MJ not used past mnth/Used MJ & othr drug past mo'
                  1='(1) Marijuana only (illicit) drug in past month' ;
  VALUE iemflagx  0='(0) Never used drug/used only marijuana'
                  1='(1) Illicit drug except for marijuana are ever used' ;
  VALUE iemyrx    0='(0) Never used drug/used only marijuana past year'
                  1='(1) Illicit drug except for marijuana used past year' ;
  VALUE iemmonx   0='(0) Never used drug/used only marijuana past month'
                  1='(1) Illicit drug except for marijuana used past month' ;
*/


* SAS DATA, INFILE, INPUT STATEMENTS;

DATA;
INFILE "data-filename" LRECL=793;
INPUT
        CASEID 790-793          RESPID 1-5              ENCPSU 6-8
        ENCSEG 9-11             ENCCASE 12-15           CIGMORLS 16-17
        CIGTRY 18-19            CIG5PK 20-21            CIGREC 22-23
        AVCIG 24-25             MORLSMJ 26-27           MORLSSED 28-29
        MORLSTRN 30-31          MORLSAMP 32-33          MORLSCOC 34-35
        MORLSLSD 36-37          MORLSHER 38-39          ADDALC 40
        ADDMJ 41                ADDSED 42               ADDTRAN 43
        ADDAMP 44               ADDCOC 45               ADDLSD 46
        ADDHER 47               ADDNONE 48              ALCTRY 49-50
        ALCREC 51-52            ALCDAYS 53-54           ALCPREF 55-56
        MJKNEW 57-58            MJOPP 59-60             MJAGE 61-62
        MJTOT 63-64             MJREC 65-66             MJDAY30A 67-68
        MJAV30A 69-70           MJEVERMT 71-72          MJALOFT 73-74
        RXBUTSOL 75             RXBUTCAP 76             RXAMYTAL 77
        RXESKAB 78              RXLUMNAL 79             RXMEBRAL 80
        RXAMOBAR 81             RXPHNBAR 82             RXALURAT 83
        RXPLACID 84             RXDORDEN 85             RXNOLDAR 86
        RXSOPOR 87              RXQUAAL 88              RXPAREST 89
        RXNOCTEC 90             RXMTHQUA 91             RXCHHYD 92
        RXNEMTAL 93             RXCARBR 94              RXSECNAL 95
        RXTUINAL 96             RXPENTOB 97             RXSECOB 98
        RXDALMAN 99             RXSEDOTH 100            RXSEDDK 101
        SEDBOR 102              SEDBOR30 103-104        RXNOSED 105
        RXSEDAGE 106-107        RXSEDREC 108-109        RXSED15D 110-111
        QUAALUDE 112-113        SECONAL 114-115         TUINAL 116-117
        PLACIDYL 118-119        SOPOR 120-121           NEMBUTAL 122-123
        SEDNEWA 124-125         SEDNEWB 126-127         NOSEDAT 128
        QUAA30DY 129-130        SECO30DY 131-132        TUIN30DY 133-134
        PLAC30DY 135-136        SOPO30DY 137-138        NEMB30DY 139-140
        SEDNWA30 141-142        SEDNWB30 143-144        NOSED30 145-146
        SEDAGE 147-148          SEDTOT 149-150          SEDREC 151-152
        SEDDAYS 153-154         SEDRX 155-156           SEDMJOCC 157-158
        SEDMORE 159-160         SEDSTOP 161-162         SEDHELP 163-164
        RXVALIUM 165            RXLIBRUM 166            RXLIBTAB 167
        RXSKLY 168              RXSERAX 169             RXTRANX 170
        RXATIVAN 171            RXVERST 172             RXMEPROS 173
        RXMILTWN 174            RXEQNIL 175             RXMEPROB 176
        RXVISTAR 177            RXATARAX 178            RXBNDRYL 179
        RXTRNOTH 180            RXTRNDK 181             TRNBOR 182
        TRNBOR30 183-184        RXNOTRAN 185            RXTRNAGE 186-187
        RXTRNREC 188-189        RXTRN15D 190-191        TRNREAD 192-193
        VALIUM 194-195          LIBRIUM 196-197         BENADRYL 198-199
        TRANXENE 200-201        EQUANIL 202-203         LIBRITAB 204-205
        TRNEWA 206-207          TRNEWB 208-209          NOTRANQ 210
        VALM30DY 211-212        LBRM30DY 213-214        BENA30DY 215-216
        TRNX30DY 217-218        EQNL30DY 219-220        LBTB30DY 221-222
        TRNEWA30 223-224        TRNEWB30 225-226        NOTRAN30 227-228
        TRANAGE 229-230         TRANTOT 231-232         TRANREC 233-234
        TRANDAYS 235-236        TRNRX 237-238           TRNMJOCC 239-240
        TRNMORE 241-242         TRNSTOP 243-244         TRNHELP 245-246
        TRNMARK 247-248         RXDEXED 249             RXDEXAM 250
        RXESKAT 251             RXBENZ 252              RXBIPHET 253
        RXDESOX 254             RXDETAMP 255            RXMETHED 256
        RXOBLA 257              RXTENUAT 258            RXTEPAN 259
        RXDIDREX 260            RXPLEGIN 261            RXPRELUD 262
        RXPRESAT 263            RXINAMIN 264            RXPONMIN 265
        RXVORNIL 266            RXSANREX 267            RXRITLIN 268
        RXCYLERT 269            RXSTMOTH 270            RXSTMDK 271
        STMBOR 272              STMBOR30 273-274        RXNOSTM 275
        RXSTMAGE 276-277        RXSTMREC 278-279        RXSTM15D 280-281
        STMREAD 282-283         DEXED 284-285           BENZ 286-287
        BIPHET 288-289          DEXAMYL 290-291         DESOXYN 292-293
        PRELUDIN 294-295        STIMNEWA 296-297        STIMNEWB 298-299
        NOSTIMS 300             DXDR30DY 301-302        BNDR30DY 303-304
        BPHT30DY 305-306        DXML30DY 307-308        DSOX30DY 309-310
        PREL30DY 311-312        STMNWA30 313-314        STMNWB30 315-316
        NOSTIM30 317-318        STIMAGE 319-320         STIMTOT 321-322
        STIMREC 323-324         STIMDAYS 325-326        STIMRX 327-328
        STMMJOCC 329-330        STMMORE 331-332         STMSTOP 333-334
        STMHELP 335-336         RXDARVON 337            RXDOLENE 338
        RXSK65 339              RXPROPOX 340            RXLERITN 341
        RXLEVODR 342            RXPERCOD 343            RXDEMROL 344
        RXDILAUD 345            RXTYLCOD 346            RXCODENE 347
        RXDOLOPH 348            RXWESTOD 349            RXMETHAD 350
        RXTALWIN 351            RXANLOTH 352            RXANLDK 353
        ANLBOR 354              ANLBOR30 355-356        RXNOANL 357
        RXANLAGE 358-359        RXANLREC 360-361        RXANL15D 362-363
        ANLREAD 364-365         DARVON 366-367          PERCODAN 368-369
        DEMEROL 370-371         DILAUD 372-373          TYLCOD 374-375
        CODEINE 376-377         ANALNEWA 378-379        ANALNEWB 380-381
        ANALNONE 382            DARV30DY 383-384        PERC30DY 385-386
        DEME30DY 387-388        DLAU30DY 389-390        TCOD30DY 391-392
        CDNE30DY 393-394        ANLNWA30 395-396        ANLNWB30 397-398
        ANALNO30 399-400        ANALAGE 401-402         ANALTOT 403-404
        ANALREC 405-406         ANALDAYS 407-408        ANALRX 409-410
        ANLMJOCC 411-412        ANALMORE 413-414        ANALSTOP 415-416
        ANALHELP 417-418        COCKNEW 419-420         COCOPP 421-422
        COCAGE 423-424          COCTOT 425-426          COCREC 427-428
        COCUS30A 429-430        COCMJOFT 431-432        HALREAD 433-434
        HALLKNEW 435-436        HALLOPP 437-438         HALLAGE 439-440
        HALLTOT 441-442         HALLREC 443-444         HAL30USE 445-446
        HALMJOFT 447-448        PCP 449-450             PCPREC 451-452
        UNSTAHAL 453-454        SECNDOTH 455-456        SECNDMJR 457-458
        HERREAD 459-460         HERKNEW 461-462         HEROPP 463-464
        HERAGE 465-466          HERTOT 467-468          HERREC 469-470
        HER30USE 471-472        HERNEEDL 473-474        FYRMJTRY 475-476
        FYRPLMTR 477-478        FYRPLNTR 479-480        FYRCOCTR 481
        FYRHALTR 482            FYRHERTR 483            FYRNONTR 484
        MJ30BUY 485-486         MJ30LBS 487-488         MJBUCK 489-492
        EFFDEPRS 493-494        EFFARGUM 495-496        EFFACDNT 497-498
        EFFSCHL 499-500         EFFWORK 501-502         ODHELP 503-504
        CLOSFRNS 505-506        FRNSHER 507-508         FRNSEX 509-510
        FRNAGE 511-512          FRNTRYH 513-514         FRNRECH 515-516
        KNOWUSEH 517-518        OTHKNOW 519-520         INSTATE 521-522
        INSTATE2 523-524        ETHRACE 525-526         HISP 527-528
        SEX 529                 RESPAGE 530-531         RAGEGRP 532-533
        ENRLCOLL 534-535        TYPESCHL 536-537        STDFTPT 538-539
        EDUC 540-541            VETERAN 542-543         MARITAL 544-545
        EMPLOY30 546-547        OCCUPAT 548-549         NOLABOR 550-551
        TOTPEOP 552-553         CHILDREN 554-555        AGEUN12 556-557
        AGE1217 558-559         AGE18OVR 560-561        HHSPOUS 562-563
        NUMPAREN 564-565        NUMSIBLN 566-567        NUMOTREL 568-569
        NUMFRNDS 570-571        NUMOTPER 572-573        NUMTOT 574-575
        CWE 576-577             CWEOCC 578-579          MILITARY 580-581
        INCOME 582-583          YTHEDUC 584-585         YTHSTUD 586-587
        YSTDFTPT 588-589        HMWRKHRS 590-591        JOBHOURS 592-593
        FUNHOURS 594-595        DATETIMS 596-597        YTOTPEOP 598-599
        NUMYSIBS 600-601        NUMOSIBS 602-603        MOTHER 604-605
        FATHER 606-607          YTHOTREL 608-609        YTHOTPER 610-611
        YNUMTOT 612-613         OTHSIBS 614-615         YTHCWE30 616-617
        YTHOCCUP 618-619        YNOLABOR 620-621        YTHMLTRY 622-623
        INTMO 624-625           INTDA 626-627           HHAREA 628-629
        UNDINT 630-631          COOPINT 632-633         ESTRACE 634-635
        PRIVACY 636-637         QUEXTYPE 638            ADULTYTH 639
        ADLTQCD 640             TOTHHVIS 641-642        FINLRES1 643-644
        VSADLTCM 645-646        PHADLTCM 647-648        VSYTHCM 649-650
        PHYTHCM 651-652         DIVISION 653            REGION 654
        POPDENX 655             IRAGE 656-657           IIAGE 658
        IRSEX 659               IISEX 660               IRRACEX 661
        IIRACEX 662             IRHOIND 663             IIHOIND 664
        IRHOGRP 665-666         IIHOGRP 667             IRMARIT 668-669
        IIMARIT 670             IREDUC 671-672          IIEDUC 673
        IRALCRC 674             IIALCRC 675             IRMJRC 676
        IIMJRC 677              IRCOCRC 678             IICOCRC 679
        IRSEDRC 680             IISEDRC 681             IRTRANRC 682
        IITRANRC 683            IRSTIMRC 684            IISTIMRC 685
        IRANALRC 686            IIANALRC 687            IRCIGRC 688
        IICIGRC 689             IRHALLRC 690            IIHALLRC 691
        IRHERRC 692             IIHERRC 693             IRPCPRC 694
        IIPCPRC 695             CATAGE 696              CATAG2 697
        CATAG3 698              RACE 699                HISPRACE 700
        EDUCCAT2 701            HALFLAG 702             HALYR 703
        HALMON 704              PCPFLAG 705             PCPYRX 706
        PCPMON 707              STMFLAG 708             STMYR 709
        STMMON 710              SEDFLAG 711             SEDYR 712
        SEDMON 713              TRQFLAG 714             TRQYR 715
        TRQMON 716              ANLFLAG 717             ANLYR 718
        ANLMON 719              ALCFLAG 720             ALCYR 721
        ALCMON 722              CIGFLAG 723             CIGYR 724
        CIGMON 725              HERFLAG 726             HERYR 727
        HERMON 728              MRJFLAG 729             MRJYR 730
        MRJMON 731              COCFLAG 732             COCYR 733
        COCMON 734              PSYFLAG2 735            PSYYR2 736
        PSYMON2 737             SUMFLAGX 738            SUMYRX 739
        SUMMONX 740             MJOFLAGX 741            MJOYR2X 742
        MJOMON2X 743            IEMFLAGX 744            IEMYRX 745
        IEMMONX 746             VESTR 747-753           VEREP 754
        ANALWT 755-765 .4       INITWTP 766-776 .4      INITWT 777-783 .4
        WT2 784-789 .4          ;


* SAS LABEL STATEMENT;

LABEL
   CASEID  = 'CASE IDENTIFICATION NUMBER'
   RESPID  = 'RESPID'
   ENCPSU  = 'PRIMARY SAMPLING UNIT (ENCRYPTED)'
   ENCSEG  = 'SEGMENT IDENTIFICATION NUMBER (ENCRYPTED'
   ENCCASE = 'HOUSEHOLD LEVEL IDENTIFICATION NUMBER (E'
   CIGMORLS= 'PEOPLE SMOKE MORE OR LESS NOW'
   CIGTRY  = 'AGE WHEN 1ST TRIED CIGARETTES'
   CIG5PK  = 'SMOKED 5 PACKS OR MORE IN LIFETIME'
   CIGREC  = 'MOST RECENT TIME SMOKED CIGARETTE'
   AVCIG   = 'AVG NUMBER CIGARETTES/DAY IN PAST MONTH'
   MORLSMJ = 'MORE OR FEWER PEOPLE USE MARIJUANA NOW'
   MORLSSED= 'MORE OR FEWER PEOPLE USE SEDATIVES NOW'
   MORLSTRN= 'MORE OR FEWER PEOPLE USE TRANQUILIZERS N'
   MORLSAMP= 'MORE OR FEWER PEOPLE USE AMPHETAMINES NO'
   MORLSCOC= 'MORE OR FEWER PEOPLE USE COCAINE NOW'
   MORLSLSD= 'MORE OR FEWER PEOPLE USE LSD NOW'
   MORLSHER= 'MORE OR FEWER PEOPLE USE HEROIN NOW'
   ADDALC  = 'THINK ALCOHOL IS ADDICTIVE'
   ADDMJ   = 'THINK MARIJUANA IS ADDICTIVE'
   ADDSED  = 'THINK SEDATIVES ARE ADDICTIVE'
   ADDTRAN = 'THINK TRANQUILIZERS ARE ADDICTIVE'
   ADDAMP  = 'THINK AMPHETAMINES ARE ADDICTIVE'
   ADDCOC  = 'THINK COCAINE IS ADDICTIVE'
   ADDLSD  = 'THINK LSD IS ADDICTIVE'
   ADDHER  = 'THINK HEROIN IS ADDICTIVE'
   ADDNONE = 'NOTHING CIRCLED AS ADDICTIVE'
   ALCTRY  = 'AGE 1ST DRANK ALCOHOLIC BEVERAGE'
   ALCREC  = 'MOST RECENT TIME HAD ALCOHOLIC DRINK'
   ALCDAYS = 'USED ALCOHOL HOW MANY DAYS IN PAST MONTH'
   ALCPREF = 'USUAL DRINK WHEN DRINKING ALCOHOL'
   MJKNEW  = 'AGE 1ST KNEW SOMEONE WHO TRIED MARIJUANA'
   MJOPP   = 'AGE 1ST OPPORTUNITY TO TRY MARIJUANA/HAS'
   MJAGE   = 'AGE 1ST TIME USED MARIJUANA/HASH'
   MJTOT   = '# TIMES USED MARIJUANA/HASH IN LIFE'
   MJREC   = 'MOST RECENT USE MARIJUANA/HASH'
   MJDAY30A= 'USED MARIJUANA/HASH HOW MANY DAYS IN PAS'
   MJAV30A = 'NUMBER MARIJUANA CIGS SMOKED PAST MONTH'
   MJEVERMT= 'EVER USE MARIJUANA/HASH ALMOST DAILY FOR'
   MJALOFT = 'HOW OFTEN USE MARIJUANA/HASH WITH ALCOHO'
   RXBUTSOL= 'EVER HAVE PRESCRIPTION FOR BUTISOL'
   RXBUTCAP= 'EVER HAVE PRESCRIPTION FOR BUTICAPS'
   RXAMYTAL= 'EVER HAVE PRESCRIPTION FOR AMYTAL'
   RXESKAB = 'EVER HAVE PRESCRIPTION FOR ESKABARB'
   RXLUMNAL= 'EVER HAVE PRESCRIPTION FOR LUMINAL'
   RXMEBRAL= 'EVER HAVE PRESCRIPTION FOR MEBARAL'
   RXAMOBAR= 'EVER HAVE PRESCRIPTION FOR AMOBARBITAL'
   RXPHNBAR= 'EVER HAVE PRESCRIPTION FOR PHENOBARBITAL'
   RXALURAT= 'EVER HAVE PRESCRIPTION FOR ALURATE'
   RXPLACID= 'EVER HAVE PRESCRIPTION FOR PLACIDYL'
   RXDORDEN= 'EVER HAVE PRESCRIPTION FOR DORIDEN'
   RXNOLDAR= 'EVER HAVE PRESCRIPTION FOR NOLUDAR'
   RXSOPOR = 'EVER HAVE PRESCRIPTION FOR SOPOR'
   RXQUAAL = 'EVER HAVE PRESCRIPTION FOR QUAALUDE'
   RXPAREST= 'EVER HAVE PRESCRIPTION FOR PAREST'
   RXNOCTEC= 'EVER HAVE PRESCRIPTION FOR NOCTEC'
   RXMTHQUA= 'EVER HAVE PRESCRIPTION FOR METHAQUALONE'
   RXCHHYD = 'EVER HAVE PRESCRIPTION FOR CHLORAL HYDRA'
   RXNEMTAL= 'EVER HAVE PRESCRIPTION FOR NEMBUTAL'
   RXCARBR = 'EVER HAVE PRESCRIPTION FOR CARBRITAL'
   RXSECNAL= 'EVER HAVE PRESCRIPTION FOR SECONAL'
   RXTUINAL= 'EVER HAVE PRESCRIPTION FOR TUINAL'
   RXPENTOB= 'EVER HAVE PRESCRIPTION FOR PENTOBARBITAL'
   RXSECOB = 'EVER HAVE PRESCRIPTION FOR SECOBARBITAL'
   RXDALMAN= 'EVER HAVE PRESCRIPTION FOR DALMANE'
   RXSEDOTH= 'EVER HAVE PRESCRIPTION FOR OTHER, THIS T'
   RXSEDDK = 'NOT SURE WHICH SEDATIVE PRESCRIPTION'
   SEDBOR  = 'BORROWED SEDATIVE FOR MEDICAL USE'
   SEDBOR30= 'MOST RECENT TIME BORROWED SEDATIVE MEDIC'
   RXNOSED = 'NEVER HAD PRESCRIPTION FOR SEDATIVE'
   RXSEDAGE= 'AGE AT FIRST SEDATIVE PRESCRIPTION'
   RXSEDREC= 'MOST RECENT TIME MEDICAL SEDATIVE USED'
   RXSED15D= 'EVER USED SED PRESCR EVERY DAY, 15 DAYS'
   QUAALUDE= 'EVER USED QUAALUDES NONMEDICALLY'
   SECONAL = 'EVER USED SECONAL NONMEDICALLY'
   TUINAL  = 'EVER USED TUINAL NONMEDICALLY'
   PLACIDYL= 'EVER USED PLACIDYL NONMEDICALLY'
   SOPOR   = 'EVER USED SOPOR NONMEDICALLY'
   NEMBUTAL= 'EVER USED NEMBUTAL NONMEDICALLY'
   SEDNEWA = 'OTHER SEDATIVE - 1'
   SEDNEWB = 'OTHER SEDATIVE - 2'
   NOSEDAT = 'NEVER USED SEDATIVES NONMEDICALLY'
   QUAA30DY= 'USED QUAALUDES NONMEDICALLY PAST MONTH'
   SECO30DY= 'USED SECONAL NONMEDICALLY PAST MONTH'
   TUIN30DY= 'USED TUINAL NONMEDICALLY PAST MONTH'
   PLAC30DY= 'USED PLACIDYL NONMEDICALLY PAST MONTH'
   SOPO30DY= 'USED SOPOR NONMEDICALLY PAST MONTH'
   NEMB30DY= 'USED NEMBUTAL NONMEDICALLY PAST MONTH'
   SEDNWA30= 'OTHER SEDATIVE - 1'
   SEDNWB30= 'OTHER SEDATIVE - 2'
   NOSED30 = 'DID NOT USE SEDATIVES NONMEDICALLY PAST'
   SEDAGE  = 'AGE 1ST SEDATIVE NONMEDICAL USE'
   SEDTOT  = '# TIMES IN LIFE USED SEDATIVES NONMED'
   SEDREC  = 'MOST RECENT NONMEDICAL SEDATIVE USE'
   SEDDAYS = 'DAYS IN PAST MONTH NONMED SEDATIVE USE'
   SEDRX   = 'EVER PRESCRIPTION FROM DOCTOR OR GET OTH'
   SEDMJOCC= 'EVER USED SEDATIVES WITH MARIJUANA'
   SEDMORE = 'EVER NEED MORE FOR SAME HIGH'
   SEDSTOP = 'TIME WHEN FOUND IT HARD TO STOP SEDATIVE'
   SEDHELP = 'EVER GET PROFESSIONAL HELP TO CUT DOWN'
   RXVALIUM= 'EVER HAVE PRESCRIPTION FOR VALIUM'
   RXLIBRUM= 'EVER HAVE PRESCRIPTION FOR LIBRIUM'
   RXLIBTAB= 'EVER HAVE PRESCRIPTION FOR LIBRITABS'
   RXSKLY  = 'EVER HAVE PRESCRIPTION FOR SK-LYGEN'
   RXSERAX = 'EVER HAVE PRESCRIPTION FOR SERAX'
   RXTRANX = 'EVER HAVE PRESCRIPTION FOR TRANXENE'
   RXATIVAN= 'EVER HAVE PRESCRIPTION FOR ATIVAN'
   RXVERST = 'EVER HAVE PRESCRIPTION FOR VERSTRAN'
   RXMEPROS= 'EVER HAVE PRESCRIPTION FOR MEPROSPAN'
   RXMILTWN= 'EVER HAVE PRESCRIPTION FOR MILTOWN'
   RXEQNIL = 'EVER HAVE PRESCRIPTION FOR EQUANIL'
   RXMEPROB= 'EVER HAVE PRESCRIPTION FOR MEPROBAMATE'
   RXVISTAR= 'EVER HAVE PRESCRIPTION FOR VISTARIL'
   RXATARAX= 'EVER HAVE PRESCRIPTION FOR ATARAX'
   RXBNDRYL= 'EVER HAVE PRESCRIPTION FOR BENADRYL'
   RXTRNOTH= 'EVER HAVE PRESCRIPTION FOR OTHER, THIS T'
   RXTRNDK = 'NOT SURE WHICH TRANQUILIZER PRESCRIPTION'
   TRNBOR  = 'BORROWED TRANQUILIZER FOR MEDICAL USE'
   TRNBOR30= 'MOST RECENT TIME BORROWED TRANQUILIZER'
   RXNOTRAN= 'NEVER HAD PRESCRIPTION FOR TRANQUILIZER'
   RXTRNAGE= 'AGE AT FIRST TRANQUILIZER PRESCRIPTION'
   RXTRNREC= 'MOST RECENT TIME MEDICAL TRANQUILIZER US'
   RXTRN15D= 'EVER USED TRANQ PRESCR EVERY DAY, 15 DAY'
   TRNREAD = 'INTERVIEWER READ ANSWER SHEET 4/FILLED O'
   VALIUM  = 'EVER USED VALIUM NONMEDICALLY'
   LIBRIUM = 'EVER USED LIBRIUM NONMEDICALLY'
   BENADRYL= 'EVER USED BENADRYL NONMEDICALLY'
   TRANXENE= 'EVER USED TRANXENE NONMEDICALLY'
   EQUANIL = 'EVER USED EQUANIL NONMEDICALLY'
   LIBRITAB= 'EVER USED LIBRITABS NONMEDICALLY'
   TRNEWA  = 'OTHER TRANQUILIZER - 1'
   TRNEWB  = 'OTHER TRANQUILIZER - 2'
   NOTRANQ = 'NEVER USED TRANQUILIZERS NONMEDICALLY'
   VALM30DY= 'USED VALIUM NONMEDICALLY PAST MONTH'
   LBRM30DY= 'USED LIBRIUM NONMEDICALLY PAST MONTH'
   BENA30DY= 'USED BENADRYL NONMEDICALLY PAST MONTH'
   TRNX30DY= 'USED TRANXENE NONMEDICALLY PAST MONTH'
   EQNL30DY= 'USED EQUANIL NONMEDICALLY PAST MONTH'
   LBTB30DY= 'USED LIBRITABS NONMEDICALLY PAST MONTH'
   TRNEWA30= 'OTHER TRANQUILIZER PAST MONTH - 1'
   TRNEWB30= 'OTHER TRANQUILIZER PAST MONTH - 2'
   NOTRAN30= 'DID NOT USE TRANQUILIZERS NONMEDICALLY P'
   TRANAGE = 'AGE 1ST NONMEDICAL TRANQUILIZER USE'
   TRANTOT = '# TIMES IN LIFE USED TRANQUILIZERS NONME'
   TRANREC = 'MOST RECENT NONMEDICAL TRANQUILIZER USE'
   TRANDAYS= 'DAYS IN PAST MONTH NONMED TRANQUILIZER U'
   TRNRX   = 'EVER PRESCRIPTION FROM DOCTOR OR GET OTH'
   TRNMJOCC= 'EVER USE TRANQUILIZERS WITH MARIJUANA'
   TRNMORE = 'EVER NEED MORE FOR SAME HIGH'
   TRNSTOP = 'EVER HAVE TROUBLE STOP TAKING TRANQS'
   TRNHELP = 'EVER GET PROFESSIONAL HELP TO STOP USE'
   TRNMARK = 'MARKED ANSWERS TO EACH QUEST BOTH SIDES'
   RXDEXED = 'EVER HAVE PRESCRIPTION FOR DEXEDRINE'
   RXDEXAM = 'EVER HAVE PRESCRIPTION FOR DEXAMYL'
   RXESKAT = 'EVER HAVE PRESCRIPTION FOR ESKATROL'
   RXBENZ  = 'EVER HAVE PRESCRIPTION FOR BENZADRINE'
   RXBIPHET= 'EVER HAVE PRESCRIPTION FOR BIPHETAMINE'
   RXDESOX = 'EVER HAVE PRESCRIPTION FOR DESOXYN'
   RXDETAMP= 'EVER HAVE PRESCRIPTION FOR DEXTROAMPHETA'
   RXMETHED= 'EVER HAVE PRESCRIPTION FOR METHEDRINE'
   RXOBLA  = 'EVER HAVE PRESCRIPTION FOR OBEDRINE-L.A.'
   RXTENUAT= 'EVER HAVE PRESCRIPTION FOR TENUATE'
   RXTEPAN = 'EVER HAVE PRESCRIPTION FOR TEPANIL'
   RXDIDREX= 'EVER HAVE PRESCRIPTION FOR DIDREX'
   RXPLEGIN= 'EVER HAVE PRESCRIPTION FOR PLEGINE'
   RXPRELUD= 'EVER HAVE PRESCRIPTION FOR PRELUDIN'
   RXPRESAT= 'EVER HAVE PRESCRIPTION FOR PRE-STATE'
   RXINAMIN= 'EVER HAVE PRESCRIPTION FOR IONAMIN'
   RXPONMIN= 'EVER HAVE PRESCRIPTION FOR PONDIMIN'
   RXVORNIL= 'EVER HAVE PRESCRIPTION FOR VORANIL'
   RXSANREX= 'EVER HAVE PRESCRIPTION FOR SANOREX'
   RXRITLIN= 'EVER HAVE PRESCRIPTION FOR RITALIN'
   RXCYLERT= 'EVER HAVE PRESCRIPTION FOR CYLERT'
   RXSTMOTH= 'EVER HAVE PRESCRIPTION FOR OTHER, THIS T'
   RXSTMDK = 'NOT SURE WHICH STIMULANT PRESCRIPTION'
   STMBOR  = 'BORROWED STIMULANT FOR MEDICAL USE'
   STMBOR30= 'MOST RECENT TIME BORROWED STIMULANT'
   RXNOSTM = 'NEVER HAD PRESCRIPTION FOR STIMULANT'
   RXSTMAGE= 'AGE AT FIRST STIMULANT PRESCRIPTION'
   RXSTMREC= 'MOST RECENT TIME MEDICAL STIMULANT USE'
   RXSTM15D= 'EVER USED STIM PRESCR EVERY DAY, 15 DAYS'
   STMREAD = 'INTERVIEWER READ ANSWER SHEET 5/FILLED O'
   DEXED   = 'EVER USED DEXEDRINE NONMEDICALLY'
   BENZ    = 'EVER USED BENZEDRINE NONMEDICALLY'
   BIPHET  = 'EVER USED BIPHETAMINE NONMEDICALLY'
   DEXAMYL = 'EVER USED DEXAMYL NONMEDICALLY'
   DESOXYN = 'EVER USED DESOXYN NONMEDICALLY'
   PRELUDIN= 'EVER USED PRELUDIN NONMEDICALLY'
   STIMNEWA= 'OTHER STIMULANT - 1'
   STIMNEWB= 'OTHER STIMULANT - 2'
   NOSTIMS = 'NEVER USED STIMULANTS NONMEDICALLY'
   DXDR30DY= 'USED DEXEDRINE NONMEDICALLY PAST MONTH'
   BNDR30DY= 'USED BENZEDRINE NONMEDICALLY PAST MONTH'
   BPHT30DY= 'USED BIPHETAMINE NONMEDICALLY PAST MONTH'
   DXML30DY= 'USED DEXAMYL NONMEDICALLY PAST MONTH'
   DSOX30DY= 'USED DESOXYN NONMEDICALLY PAST MONTH'
   PREL30DY= 'USED PRELUDIN NONMEDICALLY PAST MONTH'
   STMNWA30= 'OTHER STIMULANT PAST MONTH - 1'
   STMNWB30= 'OTHER STIMULANT PAST MONTH - 2'
   NOSTIM30= 'DID NOT USE STIMULANTS NONMEDICALLY PAST'
   STIMAGE = 'AGE 1ST NONMEDICAL STIMULANT USE'
   STIMTOT = '# TIMES IN LIFE USED STIMULANTS NONMED'
   STIMREC = 'MOST RECENT NONMEDICAL STIMULANT USE'
   STIMDAYS= 'DAYS IN PAST MONTH NONMED STIMULANT USE'
   STIMRX  = 'EVER PRESCRIPTION FROM DOCTOR OR GET OTH'
   STMMJOCC= 'EVER USE STIMULANTS WITH MARIJUANA'
   STMMORE = 'EVER NEED MORE FOR SAME HIGH'
   STMSTOP = 'EVER HAVE TROUBLE STOP TAKING STIMULANTS'
   STMHELP = 'EVER GET PROFESSIONAL HELP TO STOP USE'
   RXDARVON= 'EVER HAVE PRESCRIPTION FOR DARVON'
   RXDOLENE= 'EVER HAVE PRESCRIPTION FOR DOLENE'
   RXSK65  = 'EVER HAVE PRESCRIPTION FOR SK-65'
   RXPROPOX= 'EVER HAVE PRESCRIPTION FOR PROPOXYPHENE'
   RXLERITN= 'EVER HAVE PRESCRIPTION FOR LERITINE'
   RXLEVODR= 'EVER HAVE PRESCRIPTION FOR LEVO-DROMORAN'
   RXPERCOD= 'EVER HAVE PRESCRIPTION FOR PERCODAN'
   RXDEMROL= 'EVER HAVE PRESCRIPTION FOR DEMEROL'
   RXDILAUD= 'EVER HAVE PRESCRIPTION FOR DILAUDID'
   RXTYLCOD= 'EVER HAVE PRESCRIPTION FOR TYLENOL WITH'
   RXCODENE= 'EVER HAVE PRESCRIPTION FOR CODEINE'
   RXDOLOPH= 'EVER HAVE PRESCRIPTION FOR DOLOPHINE'
   RXWESTOD= 'EVER HAVE PRESCRIPTION FOR WESTODONE'
   RXMETHAD= 'EVER HAVE PRESCRIPTION FOR METHADONE'
   RXTALWIN= 'EVER HAVE PRESCRIPTION FOR TALWIN'
   RXANLOTH= 'EVER HAVE PRESCRIPTION FOR OTHER, THIS T'
   RXANLDK = 'NOT SURE WHICH ANALGESIC PRESCRIPTION'
   ANLBOR  = 'BORROWED ANALGESIC FOR MEDICAL USE'
   ANLBOR30= 'MOST RECENT TIME BORROWED ANALGESIC'
   RXNOANL = 'NEVER HAD PRESCRIPTION FOR ANALGESIC'
   RXANLAGE= 'AGE AT FIRST ANALGESICS PRESCRIPTION'
   RXANLREC= 'MOST RECENT MEDICAL ANALGESICS USE'
   RXANL15D= 'EVER USED ANAL PRESCR EVERY DAY, 15 DAYS'
   ANLREAD = 'INTERVIEWER READ ANSWER SHEET 6/FILLED O'
   DARVON  = 'EVER USED DARVON NONMEDICALLY'
   PERCODAN= 'EVER USED PERCODAN NONMEDICALLY'
   DEMEROL = 'EVER USED DEMEROL NONMEDICALLY'
   DILAUD  = 'EVER USED DILAUDID NONMEDICALLY'
   TYLCOD  = 'EVER USED TYLENOL-CODEINE NONMEDICALLY'
   CODEINE = 'EVER USED CODEINE NONMEDICALLY'
   ANALNEWA= 'OTHER ANALGESIC - 1'
   ANALNEWB= 'OTHER ANALGESIC - 2'
   ANALNONE= 'NEVER USED ANALGESICS NONMEDICALLY'
   DARV30DY= 'USED DARVON NONMEDICALLY PAST MONTH'
   PERC30DY= 'USED PERCODAN NONMEDICALLY PAST MONTH'
   DEME30DY= 'USED DEMEROL NONMEDICALLY PAST MONTH'
   DLAU30DY= 'USED DILAUDID NONMEDICALLY PAST MONTH'
   TCOD30DY= 'USED TYLENOL-CODEINE NONMEDICALLY PAST M'
   CDNE30DY= 'USED CODEINE NONMEDICALLY PAST MONTH'
   ANLNWA30= 'OTHER ANALGESIC PAST MONTH - 1'
   ANLNWB30= 'OTHER ANALGESIC PAST MONTH - 2'
   ANALNO30= 'DID NOT USE ANALGESICS NONMEDICALLY PAST'
   ANALAGE = 'AGE 1ST NONMEDICAL ANALGESIC USE'
   ANALTOT = '# TIMES IN LIFE USED ANALGESICS NONMED'
   ANALREC = 'MOST RECENT NONMEDICAL ANALGESIC USE'
   ANALDAYS= 'DAYS IN PAST MONTH NONMED ANALGESIC USE'
   ANALRX  = 'EVER PRESCRIPTION FROM DOCTOR OR GET OTH'
   ANLMJOCC= 'EVER USE ANALGESICS WITH MARIJUANA'
   ANALMORE= 'EVER NEED MORE FOR SAME HIGH'
   ANALSTOP= 'EVER HAVE TROUBLE STOP TAKING ANALGESICS'
   ANALHELP= 'EVER GET PROFESSIONAL HELP TO STOP USE'
   COCKNEW = 'AGE 1ST KNEW SOMEONE WHO TRIED COCAINE'
   COCOPP  = 'AGE 1ST OPPORTUNITY TO TRY COCAINE'
   COCAGE  = 'AGE 1ST TIME USED COCAINE'
   COCTOT  = '# TIMES USED COCAINE IN LIFE'
   COCREC  = 'MOST RECENT USE COCAINE'
   COCUS30A= 'USED COCAINE HOW MANY DAYS IN PAST MONTH'
   COCMJOFT= 'HOW OFTEN USED MARIJUANA WITH COCAINE'
   HALREAD = 'INTERVIEWER READ ANSWER SHEET 8/FILLED O'
   HALLKNEW= 'AGE 1ST KNEW SOMEONE WHO TRIED HALLUCINO'
   HALLOPP = 'AGE 1ST OPPORTUNITY TO TRY HALLUCINOGEN'
   HALLAGE = 'AGE 1ST TIME USED HALLUCINOGEN'
   HALLTOT = '# TIMES USED HALLUCINOGEN IN LIFE'
   HALLREC = 'MOST RECENT USE HALLUCINOGEN'
   HAL30USE= 'USED HALLUCINOGEN HOW MANY DAYS IN PAST'
   HALMJOFT= 'HOW OFTEN USE MARIJUANA WITH HALLUCINOGE'
   PCP     = 'EVER TRIED PCP'
   PCPREC  = 'MOST RECENT USE OF PCP'
   UNSTAHAL= 'UNDERSTAND LAST 2 QUESTIONS FOR ANSWER S'
   SECNDOTH= 'IF TRIED MARIJUANA 1ST WHAT WAS SECOND D'
   SECNDMJR= 'NUMBER TIMES USED MARIJUANA BEFORE 2ND D'
   HERREAD = 'INTERVIEWER READ ANSWER SHEET 10/FILLED'
   HERKNEW = 'AGE 1ST KNEW SOMEONE WHO TRIED HEROIN'
   HEROPP  = 'AGE 1ST OPPORTUNITY TO TRY HEROIN'
   HERAGE  = 'AGE 1ST TIME USED HEROIN'
   HERTOT  = '# TIMES USED HEROIN IN LIFE'
   HERREC  = 'MOST RECENT USE HEROIN'
   HER30USE= 'USED HEROIN HOW MANY DAYS IN PAST MONTH'
   HERNEEDL= 'EVER USED HEROIN WITH NEEDLE'
   FYRMJTRY= 'TRIED MARIJUANA FOR FIRST TIME IN PAST Y'
   FYRPLMTR= 'TRIED PILLS (MEDICAL) FOR FIRST TIME IN'
   FYRPLNTR= 'TRIED PILLS (NONMEDICAL) FOR FIRST TIME'
   FYRCOCTR= 'TRIED COCAINE FOR FIRST TIME IN PAST YEA'
   FYRHALTR= 'TRIED HALLUCINOGENS FOR FIRST TIME IN PA'
   FYRHERTR= 'TRIED HEROIN FOR FIRST TIME IN PAST YEAR'
   FYRNONTR= 'DID NOT TRY ANY NEW DRUGS/NEVER TRIED AN'
   MJ30BUY = 'HOW MUCH MARIJUANA BOUGHT IN PAST MONTH'
   MJ30LBS = 'HOW MANY LBS MARIJUANA BOUGHT IN PAST MO'
   MJBUCK  = 'DOLLARS SPENT FOR MARIJUANA IN PAST MONT'
   EFFDEPRS= 'SIDE EFFECT DEPRESSED/LOST INTEREST'
   EFFARGUM= 'SIDE EFFECT ARGUMENTATIVE'
   EFFACDNT= 'SIDE EFFECT AUTO ACCIDENT'
   EFFSCHL = 'SIDE EFFECT TROUBLE WITH SCHOOL'
   EFFWORK = 'SIDE EFFECT TROUBLE WITH JOB'
   ODHELP  = 'KNOW ANYONE WHO O.D.''D/NEEDED EMERGENCY'
   CLOSFRNS= 'CLOSE FRIENDS IN REGULAR HOUSEHOLDS'
   FRNSHER = 'CLOSE FRIENDS EVER USED HEROIN'
   FRNSEX  = 'SEX OF FRIEND'
   FRNAGE  = 'AGE OF FRIEND'
   FRNTRYH = '1ST TIME FRIEND TRIED HEROIN'
   FRNRECH = 'MOST RECENT TIME FRIEND USED HEROIN'
   KNOWUSEH= 'VERBATIM, HOW R CERTAIN FRIEND USED HERO'
   OTHKNOW = 'USER''S OTHER CLOSE FRIENDS WHO KNOW'
   INSTATE = 'HOW LONG LIVED IN THIS STATE'
   INSTATE2= 'HOW LONG LIVED IN THIS STATE PART 2'
   ETHRACE = 'RACE'
   HISP    = 'SPANISH-AMERICAN GROUP'
   SEX     = 'SEX'
   RESPAGE = 'AGE'
   RAGEGRP = 'DESIGNATED ADULT AGE GROUP'
   ENRLCOLL= 'CURRENT STUDENT - ADULT'
   TYPESCHL= 'TYPE OF SCHOOL'
   STDFTPT = 'FULL-TIME OR PART-TIME'
   EDUC    = 'LAST GRADE COMPLETED IN SCHOOL - ADULT'
   VETERAN = 'VETERAN'
   MARITAL = 'MARITAL STATUS'
   EMPLOY30= 'EMPLOYED IN PAST MONTH'
   OCCUPAT = 'TYPE OF EMPLOYMENT IF EMPLOYED'
   NOLABOR = 'STATUS DURING PAST MONTH IF UNEMPLOYED'
   TOTPEOP = 'HOW MANY PEOPLE LIVE HERE INCLUDING SELF'
   CHILDREN= 'ANY CHILDREN OF SELF OR SPOUSE LIVE HERE'
   AGEUN12 = 'HOW MANY CHILDREN UNDER 12'
   AGE1217 = 'HOW MANY CHILDREN 12 - 17'
   AGE18OVR= 'HOW MANY CHILDREN 18 AND OLDER'
   HHSPOUS = 'DOES SPOUSE OR SIMILAR PERSON LIVE HERE'
   NUMPAREN= 'HOW MANY PARENTS OR IN-LAWS LIVE HERE'
   NUMSIBLN= 'HOW MANY SIBLINGS LIVE HERE'
   NUMOTREL= 'HOW MANY OTHER RELATIVES LIVE HERE'
   NUMFRNDS= 'HOW MANY FRIENDS OR ROOMMATES LIVE HERE'
   NUMOTPER= 'HOW MANY OTHER NONRELATIVES LIVE HERE'
   NUMTOT  = 'TOTAL NUMBER OF PEOPLE WHO LIVE HERE'
   CWE     = 'CHIEF WAGE EARNER OTHER THAN SELF'
   CWEOCC  = 'CHIEF WAGE EARNER TYPE OF WORK'
   MILITARY= 'IMMEDIATE FAMILY MEMBER IN ARMED FORCES'
   INCOME  = 'TOTAL FAMILY INCOME'
   YTHEDUC = 'YOUTH-LAST GRADE COMPLETED IN SCHOOL'
   YTHSTUD = 'YOUTH-IN SCHOOL THIS YEAR'
   YSTDFTPT= 'YOUTH-IN SCHOOL FULL OR PART TIME'
   HMWRKHRS= 'HOURS OF HOMEWORK PER WEEK'
   JOBHOURS= 'HOURS PER WEEK IN PAID OR UNPAID JOB'
   FUNHOURS= 'HOW MANY EVENINGS OUT PER WEEK FOR FUN'
   DATETIMS= 'HOW OFTEN BOY/GIRL PARTIES OR DATES'
   YTOTPEOP= 'YOUTH-HOW MANY PEOPLE LIVE HERE INCLUDIN'
   NUMYSIBS= 'HOW MANY YOUNGER SIBLINGS LIVE HERE'
   NUMOSIBS= 'HOW MANY OLDER SIBLINGS LIVE HERE'
   MOTHER  = 'HOW MANY MOTHER OR STEPMOTHER LIVE HERE'
   FATHER  = 'HOW MANY FATHER OR STEPFATHER LIVE HERE'
   YTHOTREL= 'HOW MANY OTHER RELATIVES LIVE HERE'
   YTHOTPER= 'HOW MANY OTHER NONRELATIVES LIVE HERE'
   YNUMTOT = 'YOUTH-TOTAL NUMBER OF PEOPLE WHO LIVE HE'
   OTHSIBS = 'ANY OLDER SIBLINGS LIVE ELSEWHERE'
   YTHCWE30= 'YOUTH-CHIEF WAGE EARNER EMPLOYED PAST MO'
   YTHOCCUP= 'YOUTH-TYPE WORK CHIEF EARNER IF EMPLOYED'
   YNOLABOR= 'YOUTH-STATUS IF CHIEF NOT EMPLOYED'
   YTHMLTRY= 'YOUTH-IMMEDIATE FAMILY MEMBER IN ARMED F'
   INTMO   = 'MONTH INTERVIEW CONDUCTED'
   INTDA   = 'DAY/DATE INTERVIEW CONDUCTED'
   HHAREA  = 'TYPE OF AREA HOUSEHOLD IS IN'
   UNDINT  = 'RESPONDENT''S UNDERSTANDING OF INTERVIEW'
   COOPINT = 'RESPONDENT''S COOPERATION IN INTERVIEW'
   ESTRACE = 'RACE - INTERVIEWER''S JUDGMENT'
   PRIVACY = 'DEGREE OF PRIVACY IN INTERVIEW'
   QUEXTYPE= 'FORM USED'
   ADULTYTH= 'ADULT/YOUTH'
   ADLTQCD = 'FORM OF QUESTIONNAIRE DESIGNATED FOR ADU'
   TOTHHVIS= 'TOTAL VISITS TO THIS HOUSING UNIT'
   FINLRES1= 'FINAL ADULT RESULT'
   VSADLTCM= 'VISIT NUMBER ON WHICH ADULT INT COMPLETE'
   PHADLTCM= 'PHASE OF STUDY IN WHICH ADULT INT COMPLE'
   VSYTHCM = 'VISIT NUMBER ON WHICH YOUTH INT COMPLETE'
   PHYTHCM = 'PHASE OF STUDY IN WHICH YOUTH INT COMPLE'
   DIVISION= 'REGION'
   REGION  = 'CENSUS REGION'
   POPDENX = 'POPULATION DENSITY'
   IRAGE   = 'IMPUTATION-REVISED AGE OF RESPONDENT'
   IIAGE   = 'IRAGE INDICATOR'
   IRSEX   = 'SEX - IMPUTATION REVISED'
   IISEX   = 'IRSEX INDICATOR'
   IRRACEX = 'IMPUTATION-REVISED RACE OF RESPONDENT'
   IIRACEX = 'IRRACE INDICATOR'
   IRHOIND = 'IMPUTATION-REVISED HISPANIC ORIGIN'
   IIHOIND = 'IRHOIND INDICATOR'
   IRHOGRP = 'IMPUTATION-REVISED HISPANIC-ORIGIN GROUP'
   IIHOGRP = 'IMPUTATION INDICATOR FOR HISPANIC GROUP'
   IRMARIT = 'MARITAL STATUS - IMPUTATION INDICATOR'
   IIMARIT = 'IRMARIT INDICATOR'
   IREDUC  = 'EDUCATION - IMPUTATION REVISED'
   IIEDUC  = 'EDUCATION - IMPUTATION INDICATOR'
   IRALCRC = 'ALCOHOL RECENCY - IMPUTATION REVISED'
   IIALCRC = 'ALCOHOL RECENCY - IMPUTATION INDICATOR'
   IRMJRC  = 'MARIJUANA RECENCY - IMPUTATION REVISED'
   IIMJRC  = 'MARIJUANA RECENCY - IMPUTATION INDICATOR'
   IRCOCRC = 'COCAINE RECENCY - IMPUTATION REVISED'
   IICOCRC = 'COCAINE RECENCY - IMPUTATION INDICATOR'
   IRSEDRC = 'SEDATIVES RECENCY - IMPUTATION REVISED'
   IISEDRC = 'SEDATIVES RECENCY - IMPUTATION INDICATOR'
   IRTRANRC= 'TRANQUILIZERS RECENCY - IMPUTATION REVIS'
   IITRANRC= 'TRANQUILIZERS RECENCY - IMPUTATION INDIC'
   IRSTIMRC= 'STIMULANTS RECENCY - IMPUTATION REVISED'
   IISTIMRC= 'STIMULANTS RECENCY - IMPUTATION INDICATO'
   IRANALRC= 'ANALGESICS RECENCY - IMPUTATION REVISED'
   IIANALRC= 'ANALGESICS RECENCY - IMPUTATION INDICATO'
   IRCIGRC = 'CIGARETTES RECENCY - IMPUTATION REVISED'
   IICIGRC = 'CIGARETTES RECENCY - IMPUTATION INDICATO'
   IRHALLRC= 'HALLUCINOGENS RECENCY - IMPUTATION REVIS'
   IIHALLRC= 'HALLUCINOGENS RECENCY - IMPUTATION INDIC'
   IRHERRC = 'HEROIN RECENCY - IMPUTATION REVISED'
   IIHERRC = 'HEROIN RECENCY - IMPUTATION INDICATOR'
   IRPCPRC = 'PCP RECENCY - IMPUTATION REVISED'
   IIPCPRC = 'PCP RECENCY - IMPUTATION INDICATOR'
   CATAGE  = 'AGE CATEGORY'
   CATAG2  = 'AGE CATEGORY RECODE (3 LEVELS)'
   CATAG3  = 'AGE CATEGORY RECODE (5 LEVELS)'
   RACE    = 'RACE/HISPANIC-ORIGIN RECODE'
   HISPRACE= 'RACE ETHNICITY'
   EDUCCAT2= 'EDUCATION RECODE'
   HALFLAG = 'HALLUCINOGENS - EVER USED'
   HALYR   = 'HALLUCINOGENS - PAST YEAR USE'
   HALMON  = 'HALLUCINOGENS - PAST MONTH USE'
   PCPFLAG = 'PCP - EVER USED'
   PCPYRX  = 'PCP - PAST YEAR USE'
   PCPMON  = 'PCP - PAST MONTH USE'
   STMFLAG = 'STIMULANTS - EVER USED'
   STMYR   = 'STIMULANTS - PAST YEAR USE'
   STMMON  = 'STIMULANTS - PAST MONTH USE'
   SEDFLAG = 'SEDATIVES - EVER USED'
   SEDYR   = 'SEDATIVES - PAST YEAR USE'
   SEDMON  = 'SEDATIVES - PAST MONTH USE'
   TRQFLAG = 'TRANQUILIZERS - EVER USED'
   TRQYR   = 'TRANQUILIZERS - PAST YEAR USE'
   TRQMON  = 'TRANQUILIZERS - PAST MONTH USE'
   ANLFLAG = 'ANALGESICS - EVER USED'
   ANLYR   = 'ANALGESICS - PAST YEAR USE'
   ANLMON  = 'ANALGESICS - PAST MONTH USE'
   ALCFLAG = 'ALCOHOL - EVER USED'
   ALCYR   = 'ALCOHOL - PAST YEAR USE'
   ALCMON  = 'ALCOHOL - PAST MONTH USE'
   CIGFLAG = 'CIGARETTES - EVER USED'
   CIGYR   = 'CIGARETTES - PAST YEAR USE'
   CIGMON  = 'CIGARETTES - PAST MONTH USE'
   HERFLAG = 'HEROIN - EVER USED'
   HERYR   = 'HEROIN - PAST YEAR USE'
   HERMON  = 'HEROIN - PAST MONTH USE'
   MRJFLAG = 'MARIJUANA - EVER USED'
   MRJYR   = 'MARIJUANA - PAST YEAR USE'
   MRJMON  = 'MARIJUANA - PAST MONTH USE'
   COCFLAG = 'COCAINE - EVER USED'
   COCYR   = 'COCAINE - PAST YEAR USE'
   COCMON  = 'COCAINE - PAST MONTH USE'
   PSYFLAG2= 'ANY PSYCHOTHERAPEUTICS - EVER USED'
   PSYYR2  = 'ANY PSYCHOTHERAPEUTICS - PAST YEAR USE'
   PSYMON2 = 'ANY PSYCHOTHERAPEUTICS - PAST MONTH USE'
   SUMFLAGX= 'ANY ILLICIT DRUG - EVER USED'
   SUMYRX  = 'ANY ILLICIT DRUG - PAST YEAR USE'
   SUMMONX = 'ANY ILLICIT DRUG - PAST MONTH USE'
   MJOFLAGX= 'MARIJUANA ONLY - EVER USED'
   MJOYR2X = 'MARIJUANA ONLY - PAST YEAR USE'
   MJOMON2X= 'MARIJUANA ONLY - PAST MONTH USE'
   IEMFLAGX= 'ILLICIT DRUG EXCEPT FOR MARIJUANA - EVER'
   IEMYRX  = 'ILLICIT DRUG EXCEPT FOR MARIJUANA - PAST'
   IEMMONX = 'ILLICIT DRUG EXCEPT FOR MARIJUANA - PST'
   VESTR   = 'VARIANCE STRATUM'
   VEREP   = 'VARIANCE REPLICATE WITHIN VARIANCE STRAT'
   ANALWT  = 'ANALYSIS WEIGHT = INITWTP * WT2'
   INITWTP = 'INITIAL WEIGHT (ESTIMATES POPULATION TOT'
   INITWT  = 'INITIAL WEIGHT (SCALED TO SUM TO SAMPLE'
   WT2     = 'ADJUSTS INITWTP TO POSTSTRATUM CPS TOTAL'
        ;


* USER-DEFINED MISSING VALUES RECODE TO SAS SYSMIS;

/*
   IF (CIGMORLS >= 81) THEN CIGMORLS = .;
   IF (CIGTRY >= 81) THEN CIGTRY = .;
   IF (CIG5PK >= 81) THEN CIG5PK = .;
   IF (CIGREC >= 81) THEN CIGREC = .;
   IF (AVCIG >= 81) THEN AVCIG = .;
   IF (MORLSMJ >= 81) THEN MORLSMJ = .;
   IF (MORLSSED >= 81) THEN MORLSSED = .;
   IF (MORLSTRN >= 81) THEN MORLSTRN = .;
   IF (MORLSAMP >= 81) THEN MORLSAMP = .;
   IF (MORLSCOC >= 81) THEN MORLSCOC = .;
   IF (MORLSLSD >= 81) THEN MORLSLSD = .;
   IF (MORLSHER >= 81) THEN MORLSHER = .;
   IF (ALCTRY >= 81) THEN ALCTRY = .;
   IF (ALCREC >= 81) THEN ALCREC = .;
   IF (ALCDAYS >= 81) THEN ALCDAYS = .;
   IF (ALCPREF >= 81) THEN ALCPREF = .;
   IF (MJKNEW >= 81) THEN MJKNEW = .;
   IF (MJOPP >= 81) THEN MJOPP = .;
   IF (MJAGE >= 81) THEN MJAGE = .;
   IF (MJTOT >= 81) THEN MJTOT = .;
   IF (MJREC >= 81) THEN MJREC = .;
   IF (MJDAY30A >= 81) THEN MJDAY30A = .;
   IF (MJAV30A >= 81) THEN MJAV30A = .;
   IF (MJEVERMT >= 81) THEN MJEVERMT = .;
   IF (MJALOFT >= 81) THEN MJALOFT = .;
   IF (SEDBOR30 >= 81) THEN SEDBOR30 = .;
   IF (RXSEDAGE >= 81) THEN RXSEDAGE = .;
   IF (RXSEDREC >= 81) THEN RXSEDREC = .;
   IF (RXSED15D >= 81) THEN RXSED15D = .;
   IF (QUAALUDE >= 81) THEN QUAALUDE = .;
   IF (SECONAL >= 81) THEN SECONAL = .;
   IF (TUINAL >= 81) THEN TUINAL = .;
   IF (PLACIDYL >= 81) THEN PLACIDYL = .;
   IF (SOPOR >= 81) THEN SOPOR = .;
   IF (NEMBUTAL >= 81) THEN NEMBUTAL = .;
   IF (SEDNEWA >= 81) THEN SEDNEWA = .;
   IF (SEDNEWB >= 81) THEN SEDNEWB = .;
   IF (QUAA30DY >= 81) THEN QUAA30DY = .;
   IF (SECO30DY >= 81) THEN SECO30DY = .;
   IF (TUIN30DY >= 81) THEN TUIN30DY = .;
   IF (PLAC30DY >= 81) THEN PLAC30DY = .;
   IF (SOPO30DY >= 81) THEN SOPO30DY = .;
   IF (NEMB30DY >= 81) THEN NEMB30DY = .;
   IF (SEDNWA30 >= 81) THEN SEDNWA30 = .;
   IF (SEDNWB30 >= 81) THEN SEDNWB30 = .;
   IF (NOSED30 >= 81) THEN NOSED30 = .;
   IF (SEDAGE >= 81) THEN SEDAGE = .;
   IF (SEDTOT >= 81) THEN SEDTOT = .;
   IF (SEDREC >= 81) THEN SEDREC = .;
   IF (SEDDAYS >= 81) THEN SEDDAYS = .;
   IF (SEDRX >= 81) THEN SEDRX = .;
   IF (SEDMJOCC >= 81) THEN SEDMJOCC = .;
   IF (SEDMORE >= 81) THEN SEDMORE = .;
   IF (SEDSTOP >= 81) THEN SEDSTOP = .;
   IF (SEDHELP >= 81) THEN SEDHELP = .;
   IF (TRNBOR30 >= 81) THEN TRNBOR30 = .;
   IF (RXTRNAGE >= 81) THEN RXTRNAGE = .;
   IF (RXTRNREC >= 81) THEN RXTRNREC = .;
   IF (RXTRN15D >= 81) THEN RXTRN15D = .;
   IF (TRNREAD >= 81) THEN TRNREAD = .;
   IF (VALIUM >= 81) THEN VALIUM = .;
   IF (LIBRIUM >= 81) THEN LIBRIUM = .;
   IF (BENADRYL >= 81) THEN BENADRYL = .;
   IF (TRANXENE >= 81) THEN TRANXENE = .;
   IF (EQUANIL >= 81) THEN EQUANIL = .;
   IF (LIBRITAB >= 81) THEN LIBRITAB = .;
   IF (TRNEWA >= 81) THEN TRNEWA = .;
   IF (TRNEWB >= 81) THEN TRNEWB = .;
   IF (VALM30DY >= 81) THEN VALM30DY = .;
   IF (LBRM30DY >= 81) THEN LBRM30DY = .;
   IF (BENA30DY >= 81) THEN BENA30DY = .;
   IF (TRNX30DY >= 81) THEN TRNX30DY = .;
   IF (EQNL30DY >= 81) THEN EQNL30DY = .;
   IF (LBTB30DY >= 81) THEN LBTB30DY = .;
   IF (TRNEWA30 >= 81) THEN TRNEWA30 = .;
   IF (TRNEWB30 >= 81) THEN TRNEWB30 = .;
   IF (NOTRAN30 >= 81) THEN NOTRAN30 = .;
   IF (TRANAGE >= 81) THEN TRANAGE = .;
   IF (TRANTOT >= 81) THEN TRANTOT = .;
   IF (TRANREC >= 81) THEN TRANREC = .;
   IF (TRANDAYS >= 81) THEN TRANDAYS = .;
   IF (TRNRX >= 81) THEN TRNRX = .;
   IF (TRNMJOCC >= 81) THEN TRNMJOCC = .;
   IF (TRNMORE >= 81) THEN TRNMORE = .;
   IF (TRNSTOP >= 81) THEN TRNSTOP = .;
   IF (TRNHELP >= 81) THEN TRNHELP = .;
   IF (TRNMARK >= 81) THEN TRNMARK = .;
   IF (STMBOR30 >= 81) THEN STMBOR30 = .;
   IF (RXSTMAGE >= 81) THEN RXSTMAGE = .;
   IF (RXSTMREC >= 81) THEN RXSTMREC = .;
   IF (RXSTM15D >= 81) THEN RXSTM15D = .;
   IF (STMREAD >= 81) THEN STMREAD = .;
   IF (DEXED >= 81) THEN DEXED = .;
   IF (BENZ >= 81) THEN BENZ = .;
   IF (BIPHET >= 81) THEN BIPHET = .;
   IF (DEXAMYL >= 81) THEN DEXAMYL = .;
   IF (DESOXYN >= 81) THEN DESOXYN = .;
   IF (PRELUDIN >= 81) THEN PRELUDIN = .;
   IF (STIMNEWA >= 81) THEN STIMNEWA = .;
   IF (STIMNEWB >= 81) THEN STIMNEWB = .;
   IF (DXDR30DY >= 81) THEN DXDR30DY = .;
   IF (BNDR30DY >= 81) THEN BNDR30DY = .;
   IF (BPHT30DY >= 81) THEN BPHT30DY = .;
   IF (DXML30DY >= 81) THEN DXML30DY = .;
   IF (DSOX30DY >= 81) THEN DSOX30DY = .;
   IF (PREL30DY >= 81) THEN PREL30DY = .;
   IF (STMNWA30 >= 81) THEN STMNWA30 = .;
   IF (STMNWB30 >= 81) THEN STMNWB30 = .;
   IF (NOSTIM30 >= 81) THEN NOSTIM30 = .;
   IF (STIMAGE >= 81) THEN STIMAGE = .;
   IF (STIMTOT >= 81) THEN STIMTOT = .;
   IF (STIMREC >= 81) THEN STIMREC = .;
   IF (STIMDAYS >= 81) THEN STIMDAYS = .;
   IF (STIMRX >= 81) THEN STIMRX = .;
   IF (STMMJOCC >= 81) THEN STMMJOCC = .;
   IF (STMMORE >= 81) THEN STMMORE = .;
   IF (STMSTOP >= 81) THEN STMSTOP = .;
   IF (STMHELP >= 81) THEN STMHELP = .;
   IF (ANLBOR30 >= 81) THEN ANLBOR30 = .;
   IF (RXANLAGE >= 94) THEN RXANLAGE = .;
   IF (RXANLREC >= 81) THEN RXANLREC = .;
   IF (RXANL15D >= 81) THEN RXANL15D = .;
   IF (ANLREAD >= 81) THEN ANLREAD = .;
   IF (DARVON >= 81) THEN DARVON = .;
   IF (PERCODAN >= 81) THEN PERCODAN = .;
   IF (DEMEROL >= 81) THEN DEMEROL = .;
   IF (DILAUD >= 81) THEN DILAUD = .;
   IF (TYLCOD >= 81) THEN TYLCOD = .;
   IF (CODEINE >= 81) THEN CODEINE = .;
   IF (ANALNEWA >= 81) THEN ANALNEWA = .;
   IF (ANALNEWB >= 81) THEN ANALNEWB = .;
   IF (DARV30DY >= 81) THEN DARV30DY = .;
   IF (PERC30DY >= 81) THEN PERC30DY = .;
   IF (DEME30DY >= 81) THEN DEME30DY = .;
   IF (DLAU30DY >= 81) THEN DLAU30DY = .;
   IF (TCOD30DY >= 81) THEN TCOD30DY = .;
   IF (CDNE30DY >= 81) THEN CDNE30DY = .;
   IF (ANLNWA30 >= 81) THEN ANLNWA30 = .;
   IF (ANLNWB30 >= 81) THEN ANLNWB30 = .;
   IF (ANALNO30 >= 81) THEN ANALNO30 = .;
   IF (ANALAGE >= 81) THEN ANALAGE = .;
   IF (ANALTOT >= 81) THEN ANALTOT = .;
   IF (ANALREC >= 81) THEN ANALREC = .;
   IF (ANALDAYS >= 81) THEN ANALDAYS = .;
   IF (ANALRX >= 81) THEN ANALRX = .;
   IF (ANLMJOCC >= 81) THEN ANLMJOCC = .;
   IF (ANALMORE >= 81) THEN ANALMORE = .;
   IF (ANALSTOP >= 81) THEN ANALSTOP = .;
   IF (ANALHELP >= 81) THEN ANALHELP = .;
   IF (COCKNEW >= 81) THEN COCKNEW = .;
   IF (COCOPP >= 81) THEN COCOPP = .;
   IF (COCAGE >= 81) THEN COCAGE = .;
   IF (COCTOT >= 81) THEN COCTOT = .;
   IF (COCREC >= 81) THEN COCREC = .;
   IF (COCUS30A >= 81) THEN COCUS30A = .;
   IF (COCMJOFT >= 81) THEN COCMJOFT = .;
   IF (HALREAD >= 81) THEN HALREAD = .;
   IF (HALLKNEW >= 81) THEN HALLKNEW = .;
   IF (HALLOPP >= 81) THEN HALLOPP = .;
   IF (HALLAGE >= 81) THEN HALLAGE = .;
   IF (HALLTOT >= 81) THEN HALLTOT = .;
   IF (HALLREC >= 81) THEN HALLREC = .;
   IF (HAL30USE >= 81) THEN HAL30USE = .;
   IF (HALMJOFT >= 81) THEN HALMJOFT = .;
   IF (PCP >= 81) THEN PCP = .;
   IF (PCPREC >= 81) THEN PCPREC = .;
   IF (UNSTAHAL >= 81) THEN UNSTAHAL = .;
   IF (SECNDOTH >= 81) THEN SECNDOTH = .;
   IF (SECNDMJR >= 81) THEN SECNDMJR = .;
   IF (HERREAD >= 81) THEN HERREAD = .;
   IF (HERKNEW >= 81) THEN HERKNEW = .;
   IF (HEROPP >= 81) THEN HEROPP = .;
   IF (HERAGE >= 81) THEN HERAGE = .;
   IF (HERTOT >= 81) THEN HERTOT = .;
   IF (HERREC >= 81) THEN HERREC = .;
   IF (HER30USE >= 81) THEN HER30USE = .;
   IF (HERNEEDL >= 81) THEN HERNEEDL = .;
   IF (FYRMJTRY >= 81) THEN FYRMJTRY = .;
   IF (FYRPLMTR >= 81) THEN FYRPLMTR = .;
   IF (FYRPLNTR >= 81) THEN FYRPLNTR = .;
   IF (MJ30BUY >= 81) THEN MJ30BUY = .;
   IF (MJ30LBS >= 98) THEN MJ30LBS = .;
   IF (MJBUCK >= 9994) THEN MJBUCK = .;
   IF (EFFDEPRS >= 81) THEN EFFDEPRS = .;
   IF (EFFARGUM >= 81) THEN EFFARGUM = .;
   IF (EFFACDNT >= 81) THEN EFFACDNT = .;
   IF (EFFSCHL >= 81) THEN EFFSCHL = .;
   IF (EFFWORK >= 81) THEN EFFWORK = .;
   IF (ODHELP >= 81) THEN ODHELP = .;
   IF (CLOSFRNS >= 93) THEN CLOSFRNS = .;
   IF (FRNSHER >= 81) THEN FRNSHER = .;
   IF (FRNSEX >= 81) THEN FRNSEX = .;
   IF (FRNAGE >= 81) THEN FRNAGE = .;
   IF (FRNTRYH >= 81) THEN FRNTRYH = .;
   IF (FRNRECH >= 81) THEN FRNRECH = .;
   IF (KNOWUSEH >= 81) THEN KNOWUSEH = .;
   IF (OTHKNOW >= 81) THEN OTHKNOW = .;
   IF (INSTATE >= 81) THEN INSTATE = .;
   IF (INSTATE2 >= 81) THEN INSTATE2 = .;
   IF (ETHRACE >= 81) THEN ETHRACE = .;
   IF (HISP >= 81) THEN HISP = .;
   IF (RAGEGRP >= 81) THEN RAGEGRP = .;
   IF (ENRLCOLL >= 81) THEN ENRLCOLL = .;
   IF (TYPESCHL >= 81) THEN TYPESCHL = .;
   IF (STDFTPT >= 81) THEN STDFTPT = .;
   IF (EDUC >= 81) THEN EDUC = .;
   IF (VETERAN >= 81) THEN VETERAN = .;
   IF (MARITAL >= 81) THEN MARITAL = .;
   IF (EMPLOY30 >= 81) THEN EMPLOY30 = .;
   IF (OCCUPAT >= 81) THEN OCCUPAT = .;
   IF (NOLABOR >= 81) THEN NOLABOR = .;
   IF (TOTPEOP >= 81) THEN TOTPEOP = .;
   IF (CHILDREN >= 81) THEN CHILDREN = .;
   IF (AGEUN12 >= 81) THEN AGEUN12 = .;
   IF (AGE1217 >= 81) THEN AGE1217 = .;
   IF (AGE18OVR >= 81) THEN AGE18OVR = .;
   IF (HHSPOUS >= 81) THEN HHSPOUS = .;
   IF (NUMPAREN >= 81) THEN NUMPAREN = .;
   IF (NUMSIBLN >= 81) THEN NUMSIBLN = .;
   IF (NUMOTREL >= 81) THEN NUMOTREL = .;
   IF (NUMFRNDS >= 81) THEN NUMFRNDS = .;
   IF (NUMOTPER >= 81) THEN NUMOTPER = .;
   IF (NUMTOT >= 81) THEN NUMTOT = .;
   IF (CWE >= 81) THEN CWE = .;
   IF (CWEOCC >= 81) THEN CWEOCC = .;
   IF (MILITARY >= 81) THEN MILITARY = .;
   IF (INCOME >= 81) THEN INCOME = .;
   IF (YTHEDUC >= 81) THEN YTHEDUC = .;
   IF (YTHSTUD >= 81) THEN YTHSTUD = .;
   IF (YSTDFTPT >= 81) THEN YSTDFTPT = .;
   IF (HMWRKHRS >= 81) THEN HMWRKHRS = .;
   IF (JOBHOURS >= 81) THEN JOBHOURS = .;
   IF (FUNHOURS >= 81) THEN FUNHOURS = .;
   IF (DATETIMS >= 81) THEN DATETIMS = .;
   IF (YTOTPEOP >= 81) THEN YTOTPEOP = .;
   IF (NUMYSIBS >= 81) THEN NUMYSIBS = .;
   IF (NUMOSIBS >= 81) THEN NUMOSIBS = .;
   IF (MOTHER >= 81) THEN MOTHER = .;
   IF (FATHER >= 81) THEN FATHER = .;
   IF (YTHOTREL >= 81) THEN YTHOTREL = .;
   IF (YTHOTPER >= 81) THEN YTHOTPER = .;
   IF (YNUMTOT >= 81) THEN YNUMTOT = .;
   IF (OTHSIBS >= 81) THEN OTHSIBS = .;
   IF (YTHCWE30 >= 81) THEN YTHCWE30 = .;
   IF (YTHOCCUP >= 81) THEN YTHOCCUP = .;
   IF (YNOLABOR >= 81) THEN YNOLABOR = .;
   IF (YTHMLTRY >= 81) THEN YTHMLTRY = .;
   IF (INTMO >= 81) THEN INTMO = .;
   IF (INTDA >= 81) THEN INTDA = .;
   IF (HHAREA >= 81) THEN HHAREA = .;
   IF (UNDINT >= 81) THEN UNDINT = .;
   IF (COOPINT >= 81) THEN COOPINT = .;
   IF (ESTRACE >= 81) THEN ESTRACE = .;
   IF (PRIVACY >= 81) THEN PRIVACY = .;
   IF (TOTHHVIS >= 81) THEN TOTHHVIS = .;
   IF (FINLRES1 >= 81) THEN FINLRES1 = .;
   IF (VSADLTCM >= 81) THEN VSADLTCM = .;
   IF (PHADLTCM >= 81) THEN PHADLTCM = .;
   IF (VSYTHCM >= 81) THEN VSYTHCM = .;
   IF (PHYTHCM >= 81) THEN PHYTHCM = .;
   IF (IRHOGRP >= 81) THEN IRHOGRP = .;
   IF (IIHOGRP >= 9) THEN IIHOGRP = .;
   IF (IRMARIT >= 81) THEN IRMARIT = .;
   IF (IIMARIT >= 9) THEN IIMARIT = .;
   IF (IREDUC >= 81) THEN IREDUC = .;
   IF (IIEDUC >= 9) THEN IIEDUC = .;
   IF (IRALCRC >= 9) THEN IRALCRC = .;
   IF (IRMJRC >= 9) THEN IRMJRC = .;
   IF (IRCOCRC >= 9) THEN IRCOCRC = .;
   IF (IRSEDRC >= 9) THEN IRSEDRC = .;
   IF (IRTRANRC >= 9) THEN IRTRANRC = .;
   IF (IRSTIMRC >= 9) THEN IRSTIMRC = .;
   IF (IRANALRC >= 9) THEN IRANALRC = .;
   IF (IRCIGRC >= 9) THEN IRCIGRC = .;
   IF (IRHALLRC >= 9) THEN IRHALLRC = .;
   IF (IRHERRC >= 9) THEN IRHERRC = .;
   IF (IRPCPRC >= 9) THEN IRPCPRC = .;
*/


* SAS FORMAT STATEMENT;

/*
  FORMAT CIGMORLS cigmorls. CIGTRY cigtry. CIG5PK cig5pk.
         CIGREC cigrec. AVCIG avcig. MORLSMJ morlsmj.
         MORLSSED morlssed. MORLSTRN morlstrn. MORLSAMP morlsamp.
         MORLSCOC morlscoc. MORLSLSD morlslsd. MORLSHER morlsher.
         ADDALC addalc. ADDMJ addmj. ADDSED addsed.
         ADDTRAN addtran. ADDAMP addamp. ADDCOC addcoc.
         ADDLSD addlsd. ADDHER addher. ADDNONE addnone.
         ALCTRY alctry. ALCREC alcrec. ALCDAYS alcdays.
         ALCPREF alcpref. MJKNEW mjknew. MJOPP mjopp.
         MJAGE mjage. MJTOT mjtot. MJREC mjrec.
         MJDAY30A mjday30a. MJAV30A mjav30a. MJEVERMT mjevermt.
         MJALOFT mjaloft. RXBUTSOL rxbutsol. RXBUTCAP rxbutcap.
         RXAMYTAL rxamytal. RXESKAB rxeskab. RXLUMNAL rxlumnal.
         RXMEBRAL rxmebral. RXAMOBAR rxamobar. RXPHNBAR rxphnbar.
         RXALURAT rxalurat. RXPLACID rxplacid. RXDORDEN rxdorden.
         RXNOLDAR rxnoldar. RXSOPOR rxsopor. RXQUAAL rxquaal.
         RXPAREST rxparest. RXNOCTEC rxnoctec. RXMTHQUA rxmthqua.
         RXCHHYD rxchhyd. RXNEMTAL rxnemtal. RXCARBR rxcarbr.
         RXSECNAL rxsecnal. RXTUINAL rxtuinal. RXPENTOB rxpentob.
         RXSECOB rxsecob. RXDALMAN rxdalman. RXSEDOTH rxsedoth.
         RXSEDDK rxseddk. SEDBOR sedbor. SEDBOR30 sedbor3f.
         RXNOSED rxnosed. RXSEDAGE rxsedage. RXSEDREC rxsedrec.
         RXSED15D rxsed15d. QUAALUDE quaalude. SECONAL seconal.
         TUINAL tuinal. PLACIDYL placidyl. SOPOR sopor.
         NEMBUTAL nembutal. SEDNEWA sednewa. SEDNEWB sednewb.
         NOSEDAT nosedat. QUAA30DY quaa30dy. SECO30DY seco30dy.
         TUIN30DY tuin30dy. PLAC30DY plac30dy. SOPO30DY sopo30dy.
         NEMB30DY nemb30dy. SEDNWA30 sednwa3f. SEDNWB30 sednwb3f.
         NOSED30 nosed30f. SEDAGE sedage. SEDTOT sedtot.
         SEDREC sedrec. SEDDAYS seddays. SEDRX sedrx.
         SEDMJOCC sedmjocc. SEDMORE sedmore. SEDSTOP sedstop.
         SEDHELP sedhelp. RXVALIUM rxvalium. RXLIBRUM rxlibrum.
         RXLIBTAB rxlibtab. RXSKLY rxskly. RXSERAX rxserax.
         RXTRANX rxtranx. RXATIVAN rxativan. RXVERST rxverst.
         RXMEPROS rxmepros. RXMILTWN rxmiltwn. RXEQNIL rxeqnil.
         RXMEPROB rxmeprob. RXVISTAR rxvistar. RXATARAX rxatarax.
         RXBNDRYL rxbndryl. RXTRNOTH rxtrnoth. RXTRNDK rxtrndk.
         TRNBOR trnbor. TRNBOR30 trnbor3f. RXNOTRAN rxnotran.
         RXTRNAGE rxtrnage. RXTRNREC rxtrnrec. RXTRN15D rxtrn15d.
         TRNREAD trnread. VALIUM valium. LIBRIUM librium.
         BENADRYL benadryl. TRANXENE tranxene. EQUANIL equanil.
         LIBRITAB libritab. TRNEWA trnewa. TRNEWB trnewb.
         NOTRANQ notranq. VALM30DY valm30dy. LBRM30DY lbrm30dy.
         BENA30DY bena30dy. TRNX30DY trnx30dy. EQNL30DY eqnl30dy.
         LBTB30DY lbtb30dy. TRNEWA30 trnewa3f. TRNEWB30 trnewb3f.
         NOTRAN30 notran3f. TRANAGE tranage. TRANTOT trantot.
         TRANREC tranrec. TRANDAYS trandays. TRNRX trnrx.
         TRNMJOCC trnmjocc. TRNMORE trnmore. TRNSTOP trnstop.
         TRNHELP trnhelp. TRNMARK trnmark. RXDEXED rxdexed.
         RXDEXAM rxdexam. RXESKAT rxeskat. RXBENZ rxbenz.
         RXBIPHET rxbiphet. RXDESOX rxdesox. RXDETAMP rxdetamp.
         RXMETHED rxmethed. RXOBLA rxobla. RXTENUAT rxtenuat.
         RXTEPAN rxtepan. RXDIDREX rxdidrex. RXPLEGIN rxplegin.
         RXPRELUD rxprelud. RXPRESAT rxpresat. RXINAMIN rxinamin.
         RXPONMIN rxponmin. RXVORNIL rxvornil. RXSANREX rxsanrex.
         RXRITLIN rxritlin. RXCYLERT rxcylert. RXSTMOTH rxstmoth.
         RXSTMDK rxstmdk. STMBOR stmbor. STMBOR30 stmbor3f.
         RXNOSTM rxnostm. RXSTMAGE rxstmage. RXSTMREC rxstmrec.
         RXSTM15D rxstm15d. STMREAD stmread. DEXED dexed.
         BENZ benz. BIPHET biphet. DEXAMYL dexamyl.
         DESOXYN desoxyn. PRELUDIN preludin. STIMNEWA stimnewa.
         STIMNEWB stimnewb. NOSTIMS nostims. DXDR30DY dxdr30dy.
         BNDR30DY bndr30dy. BPHT30DY bpht30dy. DXML30DY dxml30dy.
         DSOX30DY dsox30dy. PREL30DY prel30dy. STMNWA30 stmnwa3f.
         STMNWB30 stmnwb3f. NOSTIM30 nostim3f. STIMAGE stimage.
         STIMTOT stimtot. STIMREC stimrec. STIMDAYS stimdays.
         STIMRX stimrx. STMMJOCC stmmjocc. STMMORE stmmore.
         STMSTOP stmstop. STMHELP stmhelp. RXDARVON rxdarvon.
         RXDOLENE rxdolene. RXSK65 rxsk65ff. RXPROPOX rxpropox.
         RXLERITN rxleritn. RXLEVODR rxlevodr. RXPERCOD rxpercod.
         RXDEMROL rxdemrol. RXDILAUD rxdilaud. RXTYLCOD rxtylcod.
         RXCODENE rxcodene. RXDOLOPH rxdoloph. RXWESTOD rxwestod.
         RXMETHAD rxmethad. RXTALWIN rxtalwin. RXANLOTH rxanloth.
         RXANLDK rxanldk. ANLBOR anlbor. ANLBOR30 anlbor3f.
         RXNOANL rxnoanl. RXANLAGE rxanlage. RXANLREC rxanlrec.
         RXANL15D rxanl15d. ANLREAD anlread. DARVON darvon.
         PERCODAN percodan. DEMEROL demerol. DILAUD dilaud.
         TYLCOD tylcod. CODEINE codeine. ANALNEWA analnewa.
         ANALNEWB analnewb. ANALNONE analnone. DARV30DY darv30dy.
         PERC30DY perc30dy. DEME30DY deme30dy. DLAU30DY dlau30dy.
         TCOD30DY tcod30dy. CDNE30DY cdne30dy. ANLNWA30 anlnwa3f.
         ANLNWB30 anlnwb3f. ANALNO30 analno3f. ANALAGE analage.
         ANALTOT analtot. ANALREC analrec. ANALDAYS analdays.
         ANALRX analrx. ANLMJOCC anlmjocc. ANALMORE analmore.
         ANALSTOP analstop. ANALHELP analhelp. COCKNEW cocknew.
         COCOPP cocopp. COCAGE cocage. COCTOT coctot.
         COCREC cocrec. COCUS30A cocus30a. COCMJOFT cocmjoft.
         HALREAD halread. HALLKNEW hallknew. HALLOPP hallopp.
         HALLAGE hallage. HALLTOT halltot. HALLREC hallrec.
         HAL30USE hal30use. HALMJOFT halmjoft. PCP pcp.
         PCPREC pcprec. UNSTAHAL unstahal. SECNDOTH secndoth.
         SECNDMJR secndmjr. HERREAD herread. HERKNEW herknew.
         HEROPP heropp. HERAGE herage. HERTOT hertot.
         HERREC herrec. HER30USE her30use. HERNEEDL herneedl.
         FYRMJTRY fyrmjtry. FYRPLMTR fyrplmtr. FYRPLNTR fyrplntr.
         FYRCOCTR fyrcoctr. FYRHALTR fyrhaltr. FYRHERTR fyrhertr.
         FYRNONTR fyrnontr. MJ30BUY mj30buy. MJ30LBS mj30lbs.
         MJBUCK mjbuck. EFFDEPRS effdeprs. EFFARGUM effargum.
         EFFACDNT effacdnt. EFFSCHL effschl. EFFWORK effwork.
         ODHELP odhelp. CLOSFRNS closfrns. FRNSHER frnsher.
         FRNSEX frnsex. FRNAGE frnage. FRNTRYH frntryh.
         FRNRECH frnrech. KNOWUSEH knowuseh. OTHKNOW othknow.
         INSTATE instate. INSTATE2 instatef. ETHRACE ethrace.
         HISP hisp. SEX sex. RESPAGE respage.
         RAGEGRP ragegrp. ENRLCOLL enrlcoll. TYPESCHL typeschl.
         STDFTPT stdftpt. EDUC educ. VETERAN veteran.
         MARITAL marital. EMPLOY30 employ3f. OCCUPAT occupat.
         NOLABOR nolabor. TOTPEOP totpeop. CHILDREN children.
         AGEUN12 ageun12f. AGE1217 age1217f. AGE18OVR age18ovr.
         HHSPOUS hhspous. NUMPAREN numparen. NUMSIBLN numsibln.
         NUMOTREL numotrel. NUMFRNDS numfrnds. NUMOTPER numotper.
         NUMTOT numtot. CWE cwe. CWEOCC cweocc.
         MILITARY military. INCOME income. YTHEDUC ytheduc.
         YTHSTUD ythstud. YSTDFTPT ystdftpt. HMWRKHRS hmwrkhrs.
         JOBHOURS jobhours. FUNHOURS funhours. DATETIMS datetims.
         YTOTPEOP ytotpeop. NUMYSIBS numysibs. NUMOSIBS numosibs.
         MOTHER mother. FATHER father. YTHOTREL ythotrel.
         YTHOTPER ythotper. YNUMTOT ynumtot. OTHSIBS othsibs.
         YTHCWE30 ythcwe3f. YTHOCCUP ythoccup. YNOLABOR ynolabor.
         YTHMLTRY ythmltry. INTMO intmo. INTDA intda.
         HHAREA hharea. UNDINT undint. COOPINT coopint.
         ESTRACE estrace. PRIVACY privacy. QUEXTYPE quextype.
         ADULTYTH adultyth. ADLTQCD adltqcd. TOTHHVIS tothhvis.
         FINLRES1 finlresf. VSADLTCM vsadltcm. PHADLTCM phadltcm.
         VSYTHCM vsythcm. PHYTHCM phythcm. DIVISION division.
         REGION region. POPDENX popdenx. IIAGE iiage.
         IRSEX irsex. IISEX iisex. IRRACEX irracex.
         IIRACEX iiracex. IRHOIND irhoind. IIHOIND iihoind.
         IRHOGRP irhogrp. IIHOGRP iihogrp. IRMARIT irmarit.
         IIMARIT iimarit. IREDUC ireduc. IIEDUC iieduc.
         IRALCRC iralcrc. IIALCRC iialcrc. IRMJRC irmjrc.
         IIMJRC iimjrc. IRCOCRC ircocrc. IICOCRC iicocrc.
         IRSEDRC irsedrc. IISEDRC iisedrc. IRTRANRC irtranrc.
         IITRANRC iitranrc. IRSTIMRC irstimrc. IISTIMRC iistimrc.
         IRANALRC iranalrc. IIANALRC iianalrc. IRCIGRC ircigrc.
         IICIGRC iicigrc. IRHALLRC irhallrc. IIHALLRC iihallrc.
         IRHERRC irherrc. IIHERRC iiherrc. IRPCPRC irpcprc.
         IIPCPRC iipcprc. CATAGE catage. CATAG2 catag2ff.
         CATAG3 catag3ff. RACE race. HISPRACE hisprace.
         EDUCCAT2 educcatf. HALFLAG halflag. HALYR halyr.
         HALMON halmon. PCPFLAG pcpflag. PCPYRX pcpyrx.
         PCPMON pcpmon. STMFLAG stmflag. STMYR stmyr.
         STMMON stmmon. SEDFLAG sedflag. SEDYR sedyr.
         SEDMON sedmon. TRQFLAG trqflag. TRQYR trqyr.
         TRQMON trqmon. ANLFLAG anlflag. ANLYR anlyr.
         ANLMON anlmon. ALCFLAG alcflag. ALCYR alcyr.
         ALCMON alcmon. CIGFLAG cigflag. CIGYR cigyr.
         CIGMON cigmon. HERFLAG herflag. HERYR heryr.
         HERMON hermon. MRJFLAG mrjflag. MRJYR mrjyr.
         MRJMON mrjmon. COCFLAG cocflag. COCYR cocyr.
         COCMON cocmon. PSYFLAG2 psyflagf. PSYYR2 psyyr2ff.
         PSYMON2 psymon2f. SUMFLAGX sumflagx. SUMYRX sumyrx.
         SUMMONX summonx. MJOFLAGX mjoflagx. MJOYR2X mjoyr2x.
         MJOMON2X mjomon2x. IEMFLAGX iemflagx. IEMYRX iemyrx.
         IEMMONX iemmonx.  ;
*/

RUN ;
